@@ -54,7 +54,7 @@
 #include <KoXmlWriter.h>
 #include <KoUnit.h>
 
-#include <qdom.h>
+#include <QDomDocument>
 #include <QColor>
 #include <QBrush>
 #include <QImage>
@@ -1139,14 +1139,9 @@ public:
     }
 };
 
-void Utils::rotateString(const qreal rotation, const qreal width, const qreal height, qreal& angle, qreal& xDiff, qreal& yDiff,
-    bool flipH, bool flipV)
+void Utils::rotateString(const qreal rotation, const qreal width, const qreal height, qreal& angle, qreal& xDiff, qreal& yDiff)
 {
     angle = -(qreal)rotation * ((qreal)(M_PI) / (qreal)180.0)/ (qreal)60000.0;
-    // Angle seems to be negative if one of the flips is active
-    if ((flipH && !flipV) || (!flipH && flipV)) {
-        angle = -angle;
-    }
     //position change is calculated based on the fact that center point stays in the same location
     // Width/2 = Xnew + cos(angle)*Width/2 - sin(angle)*Height/2
     // Height/2 = Ynew + sin(angle)*Width/2 + cos(angle)*Height/2
@@ -1160,6 +1155,98 @@ void Utils::setupUnderLineStyle(const QString& msooxmlName, KoCharacterStyle* te
     s_underLineStyles->setup(msooxmlName, textStyleProperties);
 }
 
+//-----------------------------------------
+// Marker styles
+//-----------------------------------------
+
+namespace
+{
+    const char* markerStyles[6] = {
+        "", "msArrowEnd_20_5", "msArrowStealthEnd_20_5", "msArrowDiamondEnd_20_5",
+        "msArrowOvalEnd_20_5", "msArrowOpenEnd_20_5"
+    };
+
+    // trying to maintain compatibility with libmso
+    enum MSOLINEEND_CUSTOM {
+        msolineNoEnd,
+        msolineArrowEnd,
+        msolineArrowStealthEnd,
+        msolineArrowDiamondEnd,
+        msolineArrowOvalEnd,
+        msolineArrowOpenEnd
+    };
+}
+
+QString Utils::defineMarkerStyle(KoGenStyles& mainStyles, const QString& type)
+{
+    uint id;
+
+    if (type == "arrow") {
+        id = msolineArrowOpenEnd;
+    } else if (type == "stealth") {
+        id = msolineArrowStealthEnd;
+    } else if (type == "diamond") {
+        id = msolineArrowDiamondEnd;
+    } else if (type == "oval") {
+        id = msolineArrowOvalEnd;
+    } else if (type == "triangle") {
+        id = msolineArrowEnd;
+    } else {
+        return QString();
+    }
+
+    const QString name(markerStyles[id]);
+
+    if (mainStyles.style(name)) {
+        return name;
+    }
+
+    KoGenStyle marker(KoGenStyle::MarkerStyle);
+    marker.addAttribute("draw:display-name",  QString(markerStyles[id]).replace("_20_", " "));
+
+    // sync with LO
+    switch (id) {
+    case msolineArrowStealthEnd:
+        marker.addAttribute("svg:viewBox", "0 0 318 318");
+        marker.addAttribute("svg:d", "m159 0 159 318-159-127-159 127z");
+        break;
+    case msolineArrowDiamondEnd:
+        marker.addAttribute("svg:viewBox", "0 0 318 318");
+        marker.addAttribute("svg:d", "m159 0 159 159-159 159-159-159z");
+        break;
+    case msolineArrowOvalEnd:
+        marker.addAttribute("svg:viewBox", "0 0 318 318");
+        marker.addAttribute("svg:d", "m318 0c0-87-72-159-159-159s-159 72-159 159 72 159 159 159 159-72 159-159z");
+        break;
+    case msolineArrowOpenEnd:
+        marker.addAttribute("svg:viewBox", "0 0 477 477");
+        marker.addAttribute("svg:d", "m239 0 238 434-72 43-166-305-167 305-72-43z");
+        break;
+    case msolineArrowEnd:
+    default:
+        marker.addAttribute("svg:viewBox", "0 0 318 318");
+        marker.addAttribute("svg:d", "m159 0 159 318h-318z");
+        break;
+    }
+    return mainStyles.insert(marker, name, KoGenStyles::DontAddNumberToName);
+}
+
+qreal Utils::defineMarkerWidth(const QString &markerWidth, const qreal lineWidth)
+{
+    int c = 0;
+
+    if (markerWidth == "lg") {
+        c = 3;
+    } else if (markerWidth == "med" || markerWidth.isEmpty()) {
+        c = 2; //MSOOXML default = "med"
+    } else if (markerWidth == "sm") {
+        c = 1;
+    }
+    return ( lineWidth * c );
+}
+
+//-----------------------------------------
+// XmlWriteBuffer
 //-----------------------------------------
 
 Utils::XmlWriteBuffer::XmlWriteBuffer()
@@ -1678,19 +1765,26 @@ QString Utils::ParagraphBulletProperties::convertToListProperties(KoGenStyles& m
     }
     else {
         out.startElement("text:list-level-style-bullet");
-        if (m_bulletChar == UNUSED) {
-            out.addAttribute("text:bullet-char", "");
+        if (m_bulletChar.length() != 1) {
+            // TODO: if there is no bullet char this should not be
+            // saved as list but as normal paragraph. Both LO and MSO
+            // do export it just as paragraph and no list until there
+            // is a fix available that change that we use a Zero Width
+            // Space to not generate invalid xml
+            out.addAttribute("text:bullet-char", QChar(0x200B));
         } else {
             out.addAttribute("text:bullet-char", m_bulletChar);
         }
     }
     out.addAttribute("text:level", m_level);
+
     //---------------------------------------------
     // text-properties
     //---------------------------------------------
-
-    //NOTE: Setting a num. of text-properties to default values if not provided
-    //for the list style to maintain compatibility with both ODF and MSOffice.
+    //
+    // NOTE: Setting a num. of text-properties to default values if
+    // not provided for the list style to maintain compatibility with
+    // both ODF and MSOffice.
 
     QString bulletSize;
     if (m_bulletRelativeSize != UNUSED) {
@@ -1701,10 +1795,9 @@ QString Utils::ParagraphBulletProperties::convertToListProperties(KoGenStyles& m
         bulletSize = "100%";
     }
 
-    if (currentFilter == Utils::DocxFilter) {
-
-        //MSWord: A label does NOT inherit Underline from text-properties of
-        //the paragraph style.  A bullet does not inherit {Italics, Bold}.
+    // MSWord: A label does NOT inherit Underline from text-properties
+    // of the paragraph style.  A bullet does not inherit {Italics, Bold}.
+    if (currentFilter == Utils::DocxFilter && m_type != ParagraphBulletProperties::PictureType) {
         if (m_type != ParagraphBulletProperties::NumberType) {
             if ((m_textStyle.property("fo:font-style")).isEmpty()) {
                 m_textStyle.addProperty("fo:font-style", "normal");
@@ -1716,16 +1809,12 @@ QString Utils::ParagraphBulletProperties::convertToListProperties(KoGenStyles& m
         if ((m_textStyle.property("style:text-underline-style")).isEmpty()) {
             m_textStyle.addProperty("style:text-underline-style", "none");
         }
-
         //fo:font-size
-        if (m_type != ParagraphBulletProperties::PictureType) {
-            if ((m_textStyle.property("fo:font-size")).isEmpty()) {
-                m_textStyle.addProperty("fo:font-size", bulletSize);
-            }
+        if ((m_textStyle.property("fo:font-size")).isEmpty()) {
+            m_textStyle.addProperty("fo:font-size", bulletSize);
         }
         out.addAttribute("text:style-name", mainStyles.insert(m_textStyle, "T"));
     }
-
     //---------------------------------------------
     // list-level-properties
     //---------------------------------------------
@@ -1841,14 +1930,13 @@ QString Utils::ParagraphBulletProperties::convertToListProperties(KoGenStyles& m
     }
     out.endElement(); //style:list-level-label-alignment
     out.endElement(); //style:list-level-properties
-    if (currentFilter != Utils::DocxFilter) {
+    if (currentFilter != Utils::DocxFilter && m_type != ParagraphBulletProperties::PictureType) {
         out.startElement("style:text-properties");
         if (m_bulletColor != UNUSED) {
             out.addAttribute("fo:color", m_bulletColor);
         }
-        if (m_type != ParagraphBulletProperties::PictureType) {
-            out.addAttribute("fo:font-size", bulletSize);
-        }
+        out.addAttribute("fo:font-size", bulletSize);
+
         //MSPowerPoint: UI does not enable to change font of a numbered lists.
         if (m_bulletFont != UNUSED) {
             if ((currentFilter != Utils::PptxFilter) || (m_type == ParagraphBulletProperties::BulletType)) {
@@ -1857,7 +1945,7 @@ QString Utils::ParagraphBulletProperties::convertToListProperties(KoGenStyles& m
         }
         //MSPowerPoint: A label does NOT inherit Underline from text-properties
         //of the 1st text chunk.  A bullet does NOT inherit {Italics, Bold}.
-        if ((currentFilter == Utils::PptxFilter)) {
+        if (currentFilter == Utils::PptxFilter) {
             if (m_type != ParagraphBulletProperties::NumberType) {
                 out.addAttribute("fo:font-style", "normal");
                 out.addAttribute("fo:font-weight", "normal");
