@@ -233,11 +233,13 @@ public:
      If \a allowOverwriting is true, user will be asked for existing
      object's overwriting, else it will be impossible to enter
      a name of existing object.
-     You can check \a allowOverwriting after calling this method.
+     You can check \a overwriteNeeded after calling this method.
      If it's true, user agreed on overwriting, if it's false, user picked
      nonexisting name, so no overwrite will be needed. */
     virtual tristate getNewObjectInfo(KexiPart::Item *partItem, KexiPart::Part *part,
-                                      bool& allowOverwriting, const QString& messageWhenAskingForName = QString()) = 0;
+                                      bool allowOverwriting,
+                                      bool *overwriteNeeded,
+                                      const QString& messageWhenAskingForName = QString()) = 0;
 
     /*! Highlights object of mime \a mime and name \a name.
      This can be done in the Project Navigator or so.
