@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005-2006 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2005-2012 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -48,6 +48,12 @@ public:
      This can be used e.g. by data-aware widgets to determine if "(autonumber)"
      label should be displayed. */
     virtual bool cursorAtNewRow() const = 0;
+
+    /*! Implement this to react when length of data has been exceeded. */
+    virtual void lengthExceeded(KexiDataItemInterface *item, bool lengthExceeded) = 0;
+
+    /*! Implement this to react when "length of data has been exceeded" message need updating. */
+    virtual void updateLengthExceededMessage(KexiDataItemInterface *item) = 0;
 };
 
 //! An interface for declaring widgets to be data-aware.
@@ -227,6 +233,11 @@ public:
     virtual bool isComboBox() const;
     
     virtual QWidget* internalEditor() const;
+
+    //! Called (e.g. by KexiDataItemInterface) to change invalid value so it is valid.
+    //! @return true on successful fixing
+    //! Default implementation just returns true.
+    virtual bool fixup();
     
 protected:
     /*! Initializes this editor with \a add value, which should be somewhat added to the current
@@ -256,6 +267,15 @@ protected:
      Used in KexiDBComboBox. */
     virtual void beforeSignalValueChanged() {}
 
+    /*! Used to indicate that length of data has been exceeded. */
+    virtual void signalLengthExceeded(bool lengthExceeded);
+
+    /*! Used to request update for "length has been exceeded" message. */
+    virtual void signalUpdateLengthExceededMessage();
+
+    /*! Emits request for showing or hiding the "Length exceeded" warning, if needed. */
+    void emitLengthExceededIfNeeded(bool lengthExceeded);
+
     KexiDataItemChangesListener* listener();
 
 //moved to KexiFormDataItemInterface: QString m_dataSource;
@@ -269,6 +289,7 @@ protected:
     bool m_hasFocusableWidget;
     bool m_disable_signalValueChanged;
     bool m_acceptEditorAfterDeleteContents;
+    bool m_lengthExceededEmittedAtPreviousChange;
 };
 
 #endif
