@@ -21,6 +21,7 @@
 #define KEXIUTILS_UTILS_H
 
 #include "kexiutils_export.h"
+#include "kexi_global.h"
 
 #include <QPointer>
 #include <QObject>
@@ -30,7 +31,7 @@
 #include <QFrame>
 
 #include <KMimeType>
-#include <kiconloader.h>
+#include <KIconLoader>
 
 class QColor;
 class QMetaProperty;
@@ -171,15 +172,6 @@ KEXIUTILS_EXPORT QList<QMetaProperty> propertiesForMetaObjectWithInherited(
 //! \return a list of enum keys for meta property \a metaProperty.
 KEXIUTILS_EXPORT QStringList enumKeysForProperty(const QMetaProperty& metaProperty);
 
-//! QDateTime - a hack needed because QVariant(QTime) has broken isNull()
-inline QDateTime stringToHackedQTime(const QString& s)
-{
-    if (s.isEmpty())
-        return QDateTime();
-    //  kDebug() << QDateTime( QDate(0,1,2), QTime::fromString( s, Qt::ISODate ) ).toString(Qt::ISODate);
-    return QDateTime(QDate(0, 1, 2), QTime::fromString(s, Qt::ISODate));
-}
-
 /*! Sets "wait" cursor with 1 second delay (or 0 seconds if noDelay is true).
  Does nothing if the application has no GUI enabled. (see KApplication::guiEnabled()) */
 KEXIUTILS_EXPORT void setWaitCursor(bool noDelay = false);
@@ -313,10 +305,10 @@ KEXIUTILS_EXPORT void simpleDecrypt(QString& string);
 KEXIUTILS_EXPORT QWidget *createDebugWindow(QWidget *parent);
 
 //! Adds debug line for for KexiDB database
-KEXIUTILS_EXPORT void addKexiDBDebug(const QString& text);
+//KEXIUTILS_EXPORT void addKexiDBDebug(const QString& text);
 
 //! Adds debug line for for Table Designer (Alter Table actions)
-KEXIUTILS_EXPORT void addAlterTableActionDebug(const QString& text, int nestingLevel = 0);
+//KEXIUTILS_EXPORT void addAlterTableActionDebug(const QString& text, int nestingLevel = 0);
 
 //! Connects push button action to \a receiver and its \a slot. This allows to execute debug-related actions
 //! using buttons displayed in the debug window.
@@ -403,112 +395,6 @@ private:
     Container& m_container;
 };
 
-//! @short Autodeleted hash
-template <class Key, class T>
-class AutodeletedHash : public QHash<Key, T>
-{
-public:
-    AutodeletedHash(const AutodeletedHash& other) : QHash<Key, T>(other), m_autoDelete(false) {}
-    AutodeletedHash(bool autoDelete = true) : QHash<Key, T>(), m_autoDelete(autoDelete) {}
-    void setAutoDelete(bool set) {
-        m_autoDelete = set;
-    }
-    bool autoDelete() const {
-        return m_autoDelete;
-    }
-    ~AutodeletedHash() {
-        if (m_autoDelete) qDeleteAll(*this);
-    }
-private:
-    bool m_autoDelete : 1;
-};
-
-//! @short Autodeleted list
-template <typename T>
-class AutodeletedList : public QList<T>
-{
-public:
-    AutodeletedList(const AutodeletedList& other)
-            : QList<T>(other), m_autoDelete(false) {}
-    AutodeletedList(bool autoDelete = true) : QList<T>(), m_autoDelete(autoDelete) {}
-    ~AutodeletedList() {
-        if (m_autoDelete) qDeleteAll(*this);
-    }
-    void setAutoDelete(bool set) {
-        m_autoDelete = set;
-    }
-    bool autoDelete() const {
-        return m_autoDelete;
-    }
-    void removeAt(int i) {
-        T item = QList<T>::takeAt(i); if (m_autoDelete) delete item;
-    }
-    void removeFirst() {
-        T item = QList<T>::takeFirst(); if (m_autoDelete) delete item;
-    }
-    void removeLast() {
-        T item = QList<T>::takeLast(); if (m_autoDelete) delete item;
-    }
-    void replace(int i, const T& value) {
-        T item = QList<T>::takeAt(i); insert(i, value); if (m_autoDelete) delete item;
-    }
-    void insert(int i, const T& value) {
-        QList<T>::insert(i, value);
-    }
-    typename QList<T>::iterator erase(typename QList<T>::iterator pos) {
-        T item = *pos;
-        typename QList<T>::iterator res = QList<T>::erase(pos);
-        if (m_autoDelete)
-            delete item;
-        return res;
-    }
-    typename QList<T>::iterator erase(
-        typename QList<T>::iterator afirst,
-        typename QList<T>::iterator alast) {
-        if (!m_autoDelete)
-            return QList<T>::erase(afirst, alast);
-        while (afirst != alast) {
-            T item = *afirst;
-            afirst = QList<T>::erase(afirst);
-            delete item;
-        }
-        return alast;
-    }
-    void pop_back() {
-        removeLast();
-    }
-    void pop_front() {
-        removeFirst();
-    }
-    int removeAll(const T& value) {
-        if (!m_autoDelete)
-            return QList<T>::removeAll(value);
-        typename QList<T>::iterator it(QList<T>::begin());
-        int removedCount = 0;
-        while (it != QList<T>::end()) {
-            if (*it == value) {
-                T item = *it;
-                it = QList<T>::erase(it);
-                delete item;
-                removedCount++;
-            } else
-                ++it;
-        }
-        return removedCount;
-    }
-    void clear() {
-        if (!m_autoDelete)
-            return QList<T>::clear();
-        while (!QList<T>::isEmpty()) {
-            T item = QList<T>::takeFirst();
-            delete item;
-        }
-    }
-
-private:
-    bool m_autoDelete : 1;
-};
-
 //! @short Case insensitive hash container supporting QString or QByteArray keys.
 //! Keys are turned to lowercase before inserting. Also supports option for autodeletion.
 template <typename Key, typename T>
@@ -569,21 +455,6 @@ private:
     bool m_autoDelete : 1;
 };
 
-//! A set created from static (0-terminated) array of raw null-terminated strings.
-class KEXIUTILS_EXPORT StaticSetOfStrings
-{
-public:
-    StaticSetOfStrings();
-    StaticSetOfStrings(const char* array[]);
-    ~StaticSetOfStrings();
-    void setStrings(const char* array[]);
-    bool isEmpty() const;
-    bool contains(const QByteArray& string) const;
-private:
-    class Private;
-    Private * const d;
-};
-
 //! Helper that sets given variable to specified value on destruction
 //! Object of type Setter are supposed to be created on the stack.
 template <typename T>
