@@ -24,17 +24,19 @@
 #include <widget/KexiConnectionSelectorWidget.h>
 #include <widget/KexiFileWidget.h>
 #include <kexiutils/utils.h>
-#include <kexidb/utils.h>
+#include <db/utils.h>
 #include <kexi_global.h>
 
-#include <qlayout.h>
-#include <qtabwidget.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpoint.h>
-#include <qobject.h>
-#include <qapplication.h>
-#include <qtooltip.h>
+#include <KoIcon.h>
+
+#include <QLayout>
+#include <QTabWidget>
+#include <QComboBox>
+#include <QCheckBox>
+#include <QPoint>
+#include <QObject>
+#include <QApplication>
+
 #include <QPixmap>
 #include <QLabel>
 #include <QKeyEvent>
@@ -74,8 +76,8 @@ public:
 //  , pageOpenRecentID(-1)
     {
         result = -1;
-        QString iconname(KexiDB::defaultFileBasedDriverIcon());
-        kexi_sqlite_icon = KIconLoader::global()->loadMimeTypeIcon(iconname, KIconLoader::Desktop);
+        QString iconname(KexiDB::defaultFileBasedDriverIconName());
+        kexi_sqlite_icon = KIcon(iconname);
         const char shortcutMimeTypeName[] = "application/x-kexiproject-shortcut";
         KMimeType::Ptr mime(KMimeType::mimeType(shortcutMimeTypeName));
         if (mime.isNull()) {
@@ -83,8 +85,7 @@ public:
             iconname.clear();
         } else
             iconname = mime->iconName();
-        kexi_shortcut_icon = KIconLoader::global()->loadMimeTypeIcon(
-                                 iconname, KIconLoader::Desktop);
+        kexi_shortcut_icon = KIcon(iconname); // TODO: no longer used?
         prj_selector = 0;
         chkDoNotShow = 0;
         openExistingConnWidget = 0;
@@ -118,7 +119,8 @@ public:
 
     int result;
 
-    QPixmap kexi_sqlite_icon, kexi_shortcut_icon;
+    KIcon kexi_sqlite_icon;
+    KIcon kexi_shortcut_icon;
 
 // //! Key string of selected database template. \sa selectedTemplateKey()
 // QString selectedTemplateKey;
@@ -170,7 +172,7 @@ KexiStartupDialog::KexiStartupDialog(
     d->dialogOptions = dialogOptions;
 
     if (dialogType == OpenExisting) {//this dialog has "open" tab only!
-        setWindowIcon(DesktopIcon("document-open"));
+        setWindowIcon(koIcon("document-open"));
     } else {
         setWindowIcon(d->kexi_sqlite_icon);
     }
@@ -352,7 +354,7 @@ void KexiStartupDialog::setupPageTemplates()
     d->templPageWidgetItem_BlankDatabase = d->templatesWidget->addPage(templPageWidget,
                                            i18n("Blank Database"));
     d->templPageWidgetItem_BlankDatabase->setHeader(i18n("New Blank Database Project"));
-    d->templPageWidgetItem_BlankDatabase->setIcon(KIcon("x-office-document"));
+    d->templPageWidgetItem_BlankDatabase->setIcon(koIcon("x-office-document"));
     tmplyr = new QVBoxLayout(templPageWidget);
     tmplyr->setSpacing(KDialog::spacingHint());
     QLabel *lbl_blank = new QLabel(
@@ -367,12 +369,11 @@ void KexiStartupDialog::setupPageTemplates()
     //- page "templates"
 // d->templatesSectionID_templates = itemID++;
     QString none;
-    QString kexi_sqlite_icon_name(KexiDB::defaultFileBasedDriverIcon());
     templPageWidget = new QFrame(d->templatesWidget);
     d->templPageWidgetItem_CreateFromTemplate = d->templatesWidget->addPage(templPageWidget,
             i18n("Create From Template"));
     d->templPageWidgetItem_CreateFromTemplate->setHeader(i18n("New Database Project From Template"));
-    d->templPageWidgetItem_CreateFromTemplate->setIcon(KIcon(kexi_sqlite_icon_name));
+    d->templPageWidgetItem_CreateFromTemplate->setIcon(d->kexi_sqlite_icon);
     tmplyr = new QVBoxLayout(templPageWidget);
     tmplyr->setSpacing(KDialog::spacingHint());
     QLabel *lbl_templ = new QLabel(
@@ -393,7 +394,7 @@ void KexiStartupDialog::setupPageTemplates()
         this,SLOT(templateItemSelected(QIconViewItem*)));*/
     /*later
       templPageFrame = d->templatesWidget->addPage (
-        i18n("Personal Databases"), i18n("New Personal Database Project Templates"), DesktopIcon("user-home") );
+        i18n("Personal Databases"), i18n("New Personal Database Project Templates"), koDesktopIcon("user-home"));
       tmplyr = new QVBoxLayout(templPageFrame, 0, KDialog::spacingHint());
       d->viewPersonalTempl = new TemplatesPage( Vertical, templPageFrame, "personal_page" );
       tmplyr->addWidget( d->viewPersonalTempl );
@@ -407,7 +408,7 @@ void KexiStartupDialog::setupPageTemplates()
       d->templatesSectionID_custom2 = itemID++;
       templPageFrame = d->templatesWidget->addPage (
         i18n("Business Databases"), i18n("New Business Database Project Templates"),
-        DesktopIcon( "user-identity" ));
+        koDesktopIcon("user-identity"));
       tmplyr = new QVBoxLayout(templPageFrame, 0, KDialog::spacingHint());
       d->viewBusinessTempl = new TemplatesPage( Vertical, templPageFrame, "business_page" );
       tmplyr->addWidget( d->viewBusinessTempl );
@@ -424,7 +425,7 @@ void KexiStartupDialog::setupPageTemplates()
                                             i18n("Import Existing Database"));
     d->templPageWidgetItem_ImportExisting->setHeader(
         i18n("Import Existing Database as New Database Project"));
-    d->templPageWidgetItem_ImportExisting->setIcon(KIcon("document_import_database"));
+    d->templPageWidgetItem_ImportExisting->setIcon(koIcon("document_import_database"));
     tmplyr = new QVBoxLayout(templPageWidget);
     tmplyr->setSpacing(KDialog::spacingHint());
     QLabel *lbl_import = new QLabel(
@@ -460,13 +461,13 @@ void KexiStartupDialog::slotCurrentTemplatesubpageChanged(KPageWidgetItem* curre
           //add items (on demand):
           d->viewTemplates->addItem("cd_catalog", i18n("CD Catalog"),
             i18n("Easy-to-use database for storing information about your CD collection."),
-            DesktopIcon("media-optical"));
+            koDesktopIcon("media-optical"));
           d->viewTemplates->addItem("expenses", i18n("Expenses"),
             i18n("A database for managing your personal expenses."),
-            DesktopIcon("accessories-calculator"));
+            koDesktopIcon("accessories-calculator"));
           d->viewTemplates->addItem("image_gallery", i18n("Image Gallery"),
             i18n("A database for archiving your image collection in a form of gallery."),
-            DesktopIcon("folder-image"));
+            koDesktopIcon("folder-image"));
         }
       }
       else if (idx==d->templatesSectionID_custom2) {//business
@@ -475,7 +476,7 @@ void KexiStartupDialog::slotCurrentTemplatesubpageChanged(KPageWidgetItem* curre
           //add items (on demand):
           d->viewBusinessTempl->addItem("address_book", i18n("Address Book"),
             i18n("A database that offers you a contact information"),
-            DesktopIcon("help-contents"));
+            koDesktopIcon("help-contents"));
         }
       }*/
 #endif
