@@ -25,7 +25,6 @@
 
 #include <KLocale>
 #include <KDebug>
-#include <KIconLoader>
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KPluginFactory>
@@ -39,8 +38,8 @@
 #include <core/kexi.h>
 #include <core/kexipart.h>
 #include <core/KexiMainWindowIface.h>
-#include <kexidb/utils.h>
-#include <kexidb/connection.h>
+#include <db/utils.h>
+#include <db/connection.h>
 #include <kexiutils/utils.h>
 #include <widget/properties/KexiCustomPropertyFactory.h>
 #include <widget/utils/kexicontextmenuutils.h>
