@@ -20,8 +20,8 @@
 
 #include "kexitableedit.h"
 #include <widget/dataviewcommon/kexidataawareobjectiface.h>
-#include <kexidb/field.h>
-#include <kexidb/utils.h>
+#include <db/field.h>
+#include <db/utils.h>
 
 #include <QPalette>
 #include <QPainter>
@@ -60,7 +60,7 @@ KexiTableEdit::KexiTableEdit(KexiTableViewColumn &column, QWidget* parent)
     QPalette pal(palette());
     pal.setBrush(backgroundRole(), pal.brush(QPalette::Base));
     setPalette(pal);
-    installEventFilter(this);
+    //installEventFilter(this);
 
     //margins
     if (displayedField()->isFPNumericType()) {
@@ -103,7 +103,7 @@ void KexiTableEdit::setViewWidget(QWidget *v)
 {
     m_view = v;
     m_view->move(0, 0);
-    m_view->installEventFilter(this);
+    //m_view->installEventFilter(this);
     setFocusProxy(m_view);
 }
 
@@ -126,6 +126,7 @@ void KexiTableEdit::resize(int w, int h)
     }
 }
 
+#if 0
 bool
 KexiTableEdit::eventFilter(QObject* watched, QEvent* e)
 {
@@ -152,6 +153,7 @@ KexiTableEdit::eventFilter(QObject* watched, QEvent* e)
     return false;
 // return QWidget::eventFilter(watched, e);
 }
+#endif
 
 void KexiTableEdit::paintFocusBorders(QPainter *p, QVariant &, int x, int y, int w, int h)
 {
