@@ -30,59 +30,42 @@
 #include "kis_node_visitor.h"
 #include "kis_processing_visitor.h"
 
-struct KisGeneratorLayer::Private
-{
-public:
-    KisFilterConfiguration * filterConfig;
-};
-
 
 KisGeneratorLayer::KisGeneratorLayer(KisImageWSP image,
                                      const QString &name,
                                      KisFilterConfiguration *kfc,
                                      KisSelectionSP selection)
-        : KisSelectionBasedLayer(image, name, selection),
-        m_d(new Private())
+    : KisSelectionBasedLayer(image, name, selection, kfc, true)
 {
-    if(kfc)
-      kfc = KisGeneratorRegistry::instance()->cloneConfiguration(kfc);
-    m_d->filterConfig = kfc;
     update();
 }
 
 KisGeneratorLayer::KisGeneratorLayer(const KisGeneratorLayer& rhs)
-        : KisSelectionBasedLayer(rhs),
-        m_d(new Private())
+        : KisSelectionBasedLayer(rhs)
 {
-    m_d->filterConfig = KisGeneratorRegistry::instance()->cloneConfiguration(rhs.m_d->filterConfig);
 }
 
 KisGeneratorLayer::~KisGeneratorLayer()
 {
-    delete m_d->filterConfig;
-    delete m_d;
 }
 
-KisFilterConfiguration * KisGeneratorLayer::filter() const
-{
-    Q_ASSERT(m_d->filterConfig);
-    return m_d->filterConfig;
-}
-
-
 void KisGeneratorLayer::setFilter(KisFilterConfiguration *filterConfig)
 {
-    Q_ASSERT(filterConfig);
-    delete m_d->filterConfig;
-    m_d->filterConfig = KisGeneratorRegistry::instance()->cloneConfiguration(filterConfig);
+    KisSelectionBasedLayer::setFilter(filterConfig);
     update();
 }
 
 
 void KisGeneratorLayer::update()
 {
+    KisSafeFilterConfigurationSP filterConfig = filter();
 
-    KisGeneratorSP f = KisGeneratorRegistry::instance()->value(m_d->filterConfig->name());
+    if (!filterConfig) {
+        warnImage << "BUG: No Filter configuration in KisGeneratorLayer";
+        return;
+    }
+
+    KisGeneratorSP f = KisGeneratorRegistry::instance()->value(filterConfig->name());
     if (!f) return;
 
     QRect processRect = exactBounds();
@@ -94,8 +77,8 @@ void KisGeneratorLayer::update()
                                     processRect.topLeft(),
                                     selection());
 
-    m_d->filterConfig->setChannelFlags(channelFlags());
-    f->generate(dstCfg, processRect.size(), m_d->filterConfig);
+    filterConfig->setChannelFlags(channelFlags());
+    f->generate(dstCfg, processRect.size(), filterConfig.data());
 }
 
 bool KisGeneratorLayer::accept(KisNodeVisitor & v)
@@ -115,9 +98,11 @@ QIcon KisGeneratorLayer::icon() const
 
 KoDocumentSectionModel::PropertyList KisGeneratorLayer::sectionModelProperties() const
 {
+    KisSafeFilterConfigurationSP filterConfig = filter();
+
     KoDocumentSectionModel::PropertyList l = KisLayer::sectionModelProperties();
     l << KoDocumentSectionModel::Property(i18n("Generator"),
-                                          KisGeneratorRegistry::instance()->value(m_d->filterConfig->name())->name());
+                                          KisGeneratorRegistry::instance()->value(filterConfig->name())->name());
     return l;
 }
 
