@@ -58,6 +58,9 @@ bool PSDColorModeBlock::read(QIODevice* io)
             i += 2;
         }
     }
+    else {
+        duotoneSpecification = data;
+    }
     return valid();
 }
 
@@ -65,14 +68,27 @@ bool PSDColorModeBlock::read(QIODevice* io)
 
 bool PSDColorModeBlock::write(QIODevice* io)
 {
-    Q_UNUSED(io);
-    Q_ASSERT(valid());
     if (!valid()) {
         error = "Cannot write an invalid Color Mode Block";
         return false;
     }
-    qFatal("TODO: implement writing the colormode block");
-    return false;
+    if (colormap.size() > 0 && colormode == Indexed) {
+        error = "Cannot write indexed color data";
+        return false;
+    }
+    else if (duotoneSpecification.size() > 0 && colormode == DuoTone) {
+        quint32 blocksize = duotoneSpecification.size();
+        psdwrite(io, blocksize);
+        if (io->write(duotoneSpecification.constData(), blocksize) != blocksize) {
+            error = "Failed to write duotone specification";
+            return false;
+        }
+    }
+    else {
+        quint32 i = 0;
+        psdwrite(io, i);
+    }
+    return true;
 }
 
 bool PSDColorModeBlock::valid()
