@@ -161,14 +161,26 @@ void KisTool::activate(ToolActivation, const QSet<KoShape*> &)
 
     connect(actions().value("toggle_fg_bg"), SIGNAL(triggered()), SLOT(slotToggleFgBg()), Qt::UniqueConnection);
     connect(actions().value("reset_fg_bg"), SIGNAL(triggered()), SLOT(slotResetFgBg()), Qt::UniqueConnection);
+    connect(image(), SIGNAL(sigStrokeCancellationRequested()), SLOT(requestStrokeCancellation()));
+    connect(image(), SIGNAL(sigStrokeEndRequested()), SLOT(requestStrokeEnd()));
 }
 
 void KisTool::deactivate()
 {
+    disconnect(image().data(), SIGNAL(sigStrokeCancellationRequested()));
+    disconnect(image().data(), SIGNAL(sigStrokeEndRequested()));
     disconnect(actions().value("toggle_fg_bg"), 0, this, 0);
     disconnect(actions().value("reset_fg_bg"), 0, this, 0);
 }
 
+void KisTool::requestStrokeCancellation()
+{
+}
+
+void KisTool::requestStrokeEnd()
+{
+}
+
 void KisTool::resourceChanged(int key, const QVariant & v)
 {
 
