@@ -39,6 +39,7 @@
 
 #include <kis_debug.h>
 
+#include <KoIcon.h>
 #include <KoCompositeOp.h>
 #include <KoUnitDoubleSpinBox.h>
 #include <KoColorSpaceRegistry.h>
@@ -101,9 +102,9 @@ KisCustomImageWidget::KisCustomImageWidget(QWidget* parent, KisDoc2* doc, qint32
     connect(createButton, SIGNAL(clicked()), this, SLOT(createImage()));
     createButton->setDefault(true);
 
-    bnPortrait->setIcon(KIcon("portrait"));
+    bnPortrait->setIcon(koIcon("portrait"));
     connect(bnPortrait, SIGNAL(toggled(bool)), SLOT(switchWidthHeight()));
-    bnLandscape->setIcon(KIcon("landscape"));
+    bnLandscape->setIcon(koIcon("landscape"));
 
     connect(bnSaveAsPredefined, SIGNAL(clicked()), this, SLOT(saveAsPredefined()));
 
