@@ -327,6 +327,7 @@ void KoPAView::initGUI()
     connect(shapeManager(), SIGNAL(contentChanged()), this, SLOT(updateCanvasSize()));
     connect(d->doc, SIGNAL(shapeAdded(KoShape *)), this, SLOT(updateCanvasSize()));
     connect(d->doc, SIGNAL(shapeRemoved(KoShape *)), this, SLOT(updateCanvasSize()));
+    connect(d->doc, SIGNAL(update(KoPAPageBase*)), this, SLOT(updateCanvasSize()));
     connect(d->canvas, SIGNAL(documentSize(const QSize&)), d->canvasController->proxyObject, SLOT(updateDocumentSize(const QSize&)));
     connect(d->canvasController->proxyObject, SIGNAL(moveDocumentOffset(const QPoint&)), d->canvas, SLOT(slotSetDocumentOffset(const QPoint&)));
     connect(d->canvasController->proxyObject, SIGNAL(sizeChanged(const QSize &)), this, SLOT(updateCanvasSize()));
@@ -334,10 +335,6 @@ void KoPAView::initGUI()
     if (shell()) {
         KoToolManager::instance()->requestToolActivation( d->canvasController );
     }
-    if (d->doc->inlineTextObjectManager()) {
-        connect(actionCollection()->action("settings_active_author"), SIGNAL(triggered(const QString &)),
-           d->doc->inlineTextObjectManager(), SLOT(activeAuthorUpdated(const QString &)));
-    }
 }
 
 void KoPAView::initActions()
