@@ -756,7 +756,7 @@ void KoTextEditor::toggleListNumbering(bool numberingEnabled)
 }
 
 void KoTextEditor::setListProperties(const KoListLevelProperties &llp,
-                                     ChangeListFlags flags)
+                                     ChangeListFlags flags, KUndo2Command *parent)
 {
     if (isEditProtected()) {
         return;
@@ -780,7 +780,7 @@ void KoTextEditor::setListProperties(const KoListLevelProperties &llp,
         }
     }
 
-    addCommand(new ChangeListCommand(d->caret, llp, flags));
+    addCommand(new ChangeListCommand(d->caret, llp, flags, parent));
     emit textFormatChanged();
 }
 
@@ -1380,6 +1380,9 @@ void KoTextEditor::insertBibliography(KoBibliographyInfo *info)
     bibFormat.setProperty( KoParagraphStyle::BibliographyData, QVariant::fromValue<KoBibliographyInfo*>(newBibInfo));
     bibFormat.setProperty( KoParagraphStyle::GeneratedDocument, QVariant::fromValue<QTextDocument*>(bibDocument));
 
+    //make sure we set up the textrangemanager on the subdocument as well
+    KoTextDocument(bibDocument).setTextRangeManager(new KoTextRangeManager);
+
     KoChangeTracker *changeTracker = KoTextDocument(d->document).changeTracker();
     if (changeTracker && changeTracker->recordChanges()) {
         QTextCharFormat charFormat = d->caret.charFormat();
