@@ -30,6 +30,7 @@
 #include "styles/KoParagraphStyle.h"
 #include "styles/KoStyleManager.h"
 #include "commands/TextPasteCommand.h"
+#include "commands/ParagraphFormattingCommand.h"
 
 #include <KLocale>
 #include <kundo2stack.h>
@@ -562,74 +563,23 @@ void KoTextEditor::mergeAutoStyle(QTextCharFormat deltaCharFormat)
 {
     d->updateState(KoTextEditor::Private::Custom, "Formatting");
 
+    int caretAnchor = d->caret.anchor();
+    int caretPosition = d->caret.position();
     MergeAutoCharacterStyleVisitor visitor(this, deltaCharFormat);
 
     recursivelyVisitSelection(d->document->rootFrame()->begin(), visitor);
 
+
+
     d->updateState(KoTextEditor::Private::NoOp);
     emit textFormatChanged();
 }
 
-class MergeAutoParagraphStyleVisitor : public KoTextVisitor
+void KoTextEditor::applyDirectFormatting(const QTextCharFormat &deltaCharFormat,
+                                  const QTextBlockFormat &deltaBlockFormat,
+                                  const KoListLevelProperties &llp)
 {
-public:
-    MergeAutoParagraphStyleVisitor(KoTextEditor *editor, QTextCharFormat deltaCharFormat, QTextBlockFormat deltaBlockFormat)
-        : KoTextVisitor(editor)
-        , m_deltaCharFormat(deltaCharFormat)
-        , m_deltaBlockFormat(deltaBlockFormat)
-    {
-    }
-
-    virtual void visitBlock(QTextBlock block, const QTextCursor &caret)
-    {
-        for (QTextBlock::iterator it = block.begin(); it != block.end(); ++it) {
-            QTextCursor fragmentSelection(caret);
-            fragmentSelection.setPosition(it.fragment().position());
-            fragmentSelection.setPosition(it.fragment().position() + it.fragment().length(), QTextCursor::KeepAnchor);
-
-            if (fragmentSelection.anchor() >= fragmentSelection.position()) {
-                continue;
-            }
-
-            visitFragmentSelection(fragmentSelection);
-        }
-
-        QList<QTextCharFormat>::Iterator it = m_formats.begin();
-        foreach(QTextCursor cursor, m_cursors) {
-            QTextFormat prevFormat(cursor.charFormat());
-            cursor.setCharFormat(*it);
-            editor()->registerTrackedChange(cursor, KoGenChange::FormatChange, i18n("Formatting"), *it, prevFormat, false);
-            ++it;
-        }
-        QTextCursor cursor(caret);
-        cursor.mergeBlockFormat(m_deltaBlockFormat);
-        cursor.mergeBlockCharFormat(m_deltaCharFormat);
-    }
-
-    virtual void visitFragmentSelection(QTextCursor fragmentSelection)
-    {
-        QTextCharFormat format = fragmentSelection.charFormat();
-        format.merge(m_deltaCharFormat);
-
-        m_formats.append(format);
-        m_cursors.append(fragmentSelection);
-    }
-
-    QTextCharFormat m_deltaCharFormat;
-    QTextBlockFormat m_deltaBlockFormat;
-    QList<QTextCharFormat> m_formats;
-    QList<QTextCursor> m_cursors;
-};
-
-void KoTextEditor::mergeAutoStyle(QTextCharFormat deltaCharFormat, QTextBlockFormat deltaBlockFormat)
-{
-    d->updateState(KoTextEditor::Private::Custom, "Formatting");
-
-    MergeAutoParagraphStyleVisitor visitor(this, deltaCharFormat, deltaBlockFormat);
-
-    recursivelyVisitSelection(d->document->rootFrame()->begin(), visitor);
-
-    d->updateState(KoTextEditor::Private::NoOp);
+    addCommand(new ParagraphFormattingCommand(this, deltaCharFormat, deltaBlockFormat, llp));
     emit textFormatChanged();
 }
 
