@@ -38,7 +38,9 @@ struct KoTextOdfSaveHelper::Private {
         , document(document)
         , from(from)
         , to(to)
+#ifdef SHOULD_BUILD_RDF
         , rdfModel(0)
+#endif
     {
     }
 
@@ -48,7 +50,9 @@ struct KoTextOdfSaveHelper::Private {
     int from;
     int to;
 
+#ifdef SHOULD_BUILD_RDF
     QSharedPointer<Soprano::Model> rdfModel; //< This is so cut/paste can serialize the relevant RDF to the clipboard
+#endif
 };
 
 
@@ -88,6 +92,7 @@ KoShapeSavingContext * KoTextOdfSaveHelper::context(KoXmlWriter * bodyWriter,
     return d->context;
 }
 
+#ifdef SHOULD_BUILD_RDF
 void KoTextOdfSaveHelper::setRdfModel(QSharedPointer<Soprano::Model> m)
 {
     d->rdfModel = m;
@@ -97,6 +102,7 @@ QSharedPointer<Soprano::Model> KoTextOdfSaveHelper::rdfModel() const
 {
     return d->rdfModel;
 }
+#endif
 
 KoStyleManager *KoTextOdfSaveHelper::styleManager() const
 {
