@@ -24,7 +24,7 @@
 #include <QFile>
 using namespace Soprano;
 
-bool KoTextRdfCore::saveRdf(Soprano::Model *model, Soprano::StatementIterator triples, KoStore *store, KoXmlWriter *manifestWriter, const QString &fileName)
+bool KoTextRdfCore::saveRdf( QSharedPointer<Soprano::Model> model, Soprano::StatementIterator triples, KoStore *store, KoXmlWriter *manifestWriter, const QString &fileName)
 {
     bool ok = false;
 
@@ -59,9 +59,9 @@ bool KoTextRdfCore::saveRdf(Soprano::Model *model, Soprano::StatementIterator tr
     return ok;
 }
 
-bool KoTextRdfCore::createAndSaveManifest(const Soprano::Model *docmodel, const QMap<QString, QString> &idmap, KoStore *store, KoXmlWriter *manifestWriter)
+bool KoTextRdfCore::createAndSaveManifest(QSharedPointer<Soprano::Model> docmodel, const QMap<QString, QString> &idmap, KoStore *store, KoXmlWriter *manifestWriter)
 {
-    Soprano::Model *tmpmodel(Soprano::createModel());
+    QSharedPointer<Soprano::Model> tmpmodel(Soprano::createModel());
     QMap<QString, QString>::const_iterator iditer = idmap.constBegin();
     QMap<QString, QString>::const_iterator idend = idmap.constEnd();
     for (; iditer != idend; ++iditer) {
@@ -100,13 +100,10 @@ bool KoTextRdfCore::createAndSaveManifest(const Soprano::Model *docmodel, const
     // save tmpmodel as manifest.rdf in C+P ODF file.
     Soprano::StatementIterator triples = tmpmodel->listStatements();
     bool ret = saveRdf(tmpmodel, triples, store, manifestWriter, "manifest.rdf");
-    if (tmpmodel) {
-        delete tmpmodel;
-    }
     return ret;
 }
 
-bool KoTextRdfCore::loadManifest(KoStore *store, Soprano::Model *model)
+bool KoTextRdfCore::loadManifest(KoStore *store, QSharedPointer<Soprano::Model> model)
 {
     bool ok = true;
     QString fileName = "manifest.rdf";
@@ -142,7 +139,7 @@ bool KoTextRdfCore::loadManifest(KoStore *store, Soprano::Model *model)
     return ok;
 }
 
-void KoTextRdfCore::dumpModel(const QString &msg, Soprano::Model *m)
+void KoTextRdfCore::dumpModel(const QString &msg, QSharedPointer<Soprano::Model> m)
 {
 #ifndef NDEBUG
     QList<Soprano::Statement> allStatements = m->listStatements().allElements();
@@ -156,7 +153,7 @@ void KoTextRdfCore::dumpModel(const QString &msg, Soprano::Model *m)
 #endif
 }
 
-QList<Soprano::Statement> KoTextRdfCore::loadList(Soprano::Model *model, Soprano::Node ListHeadSubject)
+QList<Soprano::Statement> KoTextRdfCore::loadList(QSharedPointer<Soprano::Model> model, Soprano::Node ListHeadSubject)
 {
     Node rdfNil = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#nil"));
     Node rdfFirst = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#first"));
@@ -181,7 +178,7 @@ QList<Soprano::Statement> KoTextRdfCore::loadList(Soprano::Model *model, Soprano
     return ret;
 }
 
-static void removeList(Soprano::Model *model, Soprano::Node ListHeadSubject)
+static void removeList(QSharedPointer<Soprano::Model> model, Soprano::Node ListHeadSubject)
 {
     Node rdfNil = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#nil"));
     Node rdfFirst = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#first"));
@@ -200,7 +197,7 @@ static void removeList(Soprano::Model *model, Soprano::Node ListHeadSubject)
     model->removeAllStatements(ListHeadSubject, rdfRest, Node());
 }
 
-void KoTextRdfCore::saveList(Soprano::Model *model, Soprano::Node ListHeadSubject, QList<Soprano::Node> &dataBNodeList, Soprano::Node context)
+void KoTextRdfCore::saveList(QSharedPointer<Soprano::Model> model, Soprano::Node ListHeadSubject, QList<Soprano::Node> &dataBNodeList, Soprano::Node context)
 {
     Node rdfNil = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#nil"));
     Node rdfFirst = Node::createResourceNode(QUrl("http://www.w3.org/1999/02/22-rdf-syntax-ns#first"));
@@ -233,7 +230,7 @@ void KoTextRdfCore::saveList(Soprano::Model *model, Soprano::Node ListHeadSubjec
     model->addStatement(listBNode, rdfRest, rdfNil, context);
 }
 
-void KoTextRdfCore::removeStatementsIfTheyExist(Soprano::Model *m, const QList<Soprano::Statement> &removeList)
+void KoTextRdfCore::removeStatementsIfTheyExist( QSharedPointer<Soprano::Model> m, const QList<Soprano::Statement> &removeList)
 {
     foreach (Soprano::Statement s, removeList) {
         StatementIterator it = m->listStatements(s.subject(), s.predicate(), s.object(), s.context());
@@ -245,7 +242,7 @@ void KoTextRdfCore::removeStatementsIfTheyExist(Soprano::Model *m, const QList<S
     }
 }
 
-Soprano::Node KoTextRdfCore::getObject(Soprano::Model *model, Soprano::Node s, Soprano::Node p)
+Soprano::Node KoTextRdfCore::getObject(QSharedPointer<Soprano::Model> model, Soprano::Node s, Soprano::Node p)
 {
     QList<Statement> all;
     all = model->listStatements(s, p, Node()).allElements();
@@ -262,7 +259,7 @@ QByteArray KoTextRdfCore::fileToByteArray(const QString &fileName)
     return t.readAll();
 }
 
-QString KoTextRdfCore::getProperty(Soprano::Model *m, Soprano::Node subj, Soprano::Node pred, const QString &defval)
+QString KoTextRdfCore::getProperty(QSharedPointer<Soprano::Model> m, Soprano::Node subj, Soprano::Node pred, const QString &defval)
 {
     StatementIterator it = m->listStatements(subj, pred, Node());
     QList<Statement> allStatements = it.allElements();
