@@ -229,23 +229,10 @@ QColor KoParagraphStyle::propertyColor(int key) const
 
 void KoParagraphStyle::applyStyle(QTextBlockFormat &format) const
 {
-    bool hadBreakBefore = format.hasProperty(BreakBefore);
-    bool hadBreakAfter = format.hasProperty(BreakAfter);
-
     if (d->parentStyle) {
         d->parentStyle->applyStyle(format);
     }
 
-    if (!hadBreakBefore) {
-         // page preak should not be inherited according to odf, yet if it was there
-         // before we shouldn't remove
-         format.clearProperty(BreakBefore);
-    }
-    if (!hadBreakAfter) {
-         // page preak should not be inherited according to odf, yet if it was there
-         // before we shouldn't remove
-         format.clearProperty(BreakAfter);
-    }
     const QMap<int, QVariant> props = d->stylesPrivate.properties();
     QMap<int, QVariant>::const_iterator it = props.begin();
     while (it != props.end()) {
@@ -314,9 +301,8 @@ void KoParagraphStyle::applyParagraphListStyle(QTextBlock &block, const QTextBlo
         } else {
             if (block.textList())
                 block.textList()->remove(block);
-            KoTextBlockData *data = dynamic_cast<KoTextBlockData*>(block.userData());
-            if (data)
-                data->setCounterWidth(-1);
+            KoTextBlockData data(block);
+            data.setCounterWidth(-1);
         }
     }
 }
