@@ -324,6 +324,13 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
         }
         styleStack.restore();
 
+        QString family = style->attributeNS(KoXmlNS::style, "family", "graphic");
+        KoParagraphStyle *defaultStyle = 0;
+        const KoXmlElement *dstyle = context.odfLoadingContext().stylesReader().defaultStyle(family);
+        if (dstyle) {
+            defaultStyle = new KoParagraphStyle();
+            defaultStyle->loadOdf(dstyle, context);
+        }
         // graphic styles don't support inheritance yet therefor some additional work is needed here.
         QList<KoParagraphStyle *> paragraphStyles;
         while (style) {
@@ -333,16 +340,13 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
                 paragraphStyles.last()->setParentStyle(pStyle);
             }
             paragraphStyles.append(pStyle);
-            QString family = style->attributeNS(KoXmlNS::style, "family", "paragraph");
+            QString family = style->attributeNS(KoXmlNS::style, "family", "graphic");
             style = context.odfLoadingContext().stylesReader().findStyle(
                     style->attributeNS(KoXmlNS::style, "parent-style-name"), family.toLocal8Bit().constData(),
                     context.odfLoadingContext().useStylesAutoStyles());
-            if (!style && paragraphStyles.size() == 1) {
-                style = context.odfLoadingContext().stylesReader().findStyle(
-                        "standard", family.toLocal8Bit().constData(),
-                        context.odfLoadingContext().useStylesAutoStyles());
-            }
         }
+        // rather than setting default style and apply to block we just set a final parent
+        paragraphStyles.last()->setParentStyle(defaultStyle);
 
         QTextDocument *document = this->document();
         QTextCursor cursor(document);
@@ -356,6 +360,7 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
 
         d->paragraphStyle = new KoParagraphStyle(format, cformat);
         qDeleteAll(paragraphStyles);
+        delete defaultStyle;
     }
 }
 
