@@ -44,7 +44,6 @@ KoViewItemContextBar::KoViewItemContextBar(QAbstractItemView *parent)
     : QObject(parent)
     , m_view(parent)
     , m_enabled(true)
-    , m_appliedPointingHandCursor(false)
     , m_showToggleButton(true)
 {
     connect(parent, SIGNAL(entered(const QModelIndex&)),
@@ -89,20 +88,6 @@ bool KoViewItemContextBar::eventFilter(QObject *watched, QEvent *event)
             break;
         }
     }
-    else if (watched == m_ContextBar) {
-            switch (event->type()) {
-            case QEvent::Enter:
-                QApplication::changeOverrideCursor(Qt::PointingHandCursor);
-                break;
-
-            case QEvent::Leave:
-                QApplication::changeOverrideCursor(Qt::ArrowCursor);
-                break;
-
-            default:
-                break;
-            }
-        }
     return QObject::eventFilter(watched, event);
 }
 
@@ -110,10 +95,6 @@ void KoViewItemContextBar::slotEntered(const QModelIndex &index)
 {
     const bool isSelectionCandidate = index.isValid() &&
             (QApplication::mouseButtons() == Qt::NoButton);
-    restoreCursor();
-    if (isSelectionCandidate && KGlobalSettings::singleClick()) {
-        applyPointingHandCursor();
-    }
 
     if (!m_ContextBar || !m_enabled) {
         return;
@@ -180,7 +161,6 @@ void KoViewItemContextBar::showContextBar(const QRect &rect)
 void KoViewItemContextBar::slotViewportEntered()
 {
     m_ContextBar->hide();
-    restoreCursor();
 }
 
 void KoViewItemContextBar::setItemSelected()
@@ -208,23 +188,6 @@ void KoViewItemContextBar::slotRowsRemoved(const QModelIndex &parent, int start,
     if (m_ContextBar) {
         m_ContextBar->hide();
     }
-    restoreCursor();
-}
-
-void KoViewItemContextBar::applyPointingHandCursor()
-{
-    if (!m_appliedPointingHandCursor) {
-        QApplication::setOverrideCursor(QCursor(Qt::PointingHandCursor));
-        m_appliedPointingHandCursor = true;
-    }
-}
-
-void KoViewItemContextBar::restoreCursor()
-{
-    if (m_appliedPointingHandCursor) {
-        QApplication::restoreOverrideCursor();
-        m_appliedPointingHandCursor = false;
-    }
 }
 
 void KoViewItemContextBar::updateToggleSelectionButton()
@@ -276,7 +239,6 @@ void KoViewItemContextBar::reset()
     if (m_ContextBar) {
         m_ContextBar->hide();
     }
-    restoreCursor();
 }
 
 void KoViewItemContextBar::enableContextBar()
