@@ -81,7 +81,22 @@ public:
         State_RunningEarly = 256,
         State_ReadyToStart = 512, // all precceeding tasks finished (if any)
         State_NotReadyToStart = 1024, // all precceeding tasks not finished (must be one or more)
-        State_NotScheduled = 2048
+        State_NotScheduled = 2048,
+        State_Late = 4096
+    };
+
+    enum Properties {
+        Type,
+        StartupCost,
+        ShutdownCost,
+        CompletionEntry,
+        CompletionStarted,
+        CompletionFinished,
+        CompletionStartTime,
+        CompletionFinishTime,
+        CompletionPercentage,
+        CompletionRemainingEffort,
+        CompletionActualEffort
     };
 
     Node(Node *parent = 0);
@@ -332,23 +347,29 @@ public:
     /// Returns the cost planned to be used to reach the actual percent finished
     virtual double budgetedCostPerformed( const QDate &, long = CURRENTSCHEDULE ) const { return 0.0; };
 
+    /// Return map of Budgeted Cost of Work Scheduled pr day
+    virtual EffortCostMap bcwsPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
     /// Return map of Budgeted Cost of Work Scheduled pr day
     virtual EffortCostMap bcwsPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
     /// Budgeted Cost of Work Scheduled
     virtual double bcws( const QDate &/*date*/, long id = CURRENTSCHEDULE ) const { Q_UNUSED(id); return 0.0; }
 
+    /// Return map of Budgeted Cost of Work Scheduled pr day (also includes bcws pr day)
+    virtual EffortCostMap bcwpPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
     /// Return map of Budgeted Cost of Work Scheduled pr day (also includes bcws pr day)
     virtual EffortCostMap bcwpPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
     /// Budgeted Cost of Work Performed
     virtual double bcwp( long id ) const { Q_UNUSED(id); return 0.0; }
     /// Budgeted Cost of Work Performed ( up to @p date )
     virtual double bcwp( const QDate &/*date*/, long id = CURRENTSCHEDULE ) const { Q_UNUSED(id); return 0.0; }
-    
+
+    /// Return a map of Actual effort and Cost of Work Performed
+    virtual EffortCostMap acwp( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
     /// Return a map of Actual effort and Cost of Work Performed
     virtual EffortCostMap acwp( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
     /// Return Actual effort and Cost of Work Performed upto @date
     virtual EffortCost acwp( const QDate &date, long id = CURRENTSCHEDULE ) const;
-    
+
     /// Effort based performance index
     virtual double effortPerformanceIndex(const QDate &/*date*/, long /*id*/ = CURRENTSCHEDULE ) const { return 0.0; }
     /// Schedule performance index
@@ -583,7 +604,7 @@ public:
     virtual void addParentProxyRelation(Node *, const Relation *) {}
     virtual void addChildProxyRelation(Node *, const Relation *) {}
     
-    virtual void changed() { changed( this ); }
+    virtual void changed( int property = -1 ) { changed( this, property ); }
     Duration getmDurationForward(){ return this->m_durationForward;}
 
 public slots:
@@ -600,7 +621,7 @@ protected:
 
     // NOTE: Cannot use setCurrentSchedule() due to overload/casting problems
     void setCurrentSchedulePtr(Schedule *schedule) { m_currentSchedule = schedule; }
-    virtual void changed(Node *node);
+    virtual void changed(Node *node, int property = -1 );
     
     QList<Node*> m_nodes;
     QList<Relation*> m_dependChildNodes;
