@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
   Copyright (C) 2007 Dag Andersen <danders@get2net.dk>
-  Copyright (C) 2011 Dag Andersen <danders@get2net.dk>
+  Copyright (C) 2011, 2012 Dag Andersen <danders@get2net.dk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -30,23 +30,28 @@
 #include "kpttask.h"
 #include "kptresource.h"
 #include "kptdatetime.h"
+#include "kptdebug.h"
+
+#include <KoIcon.h>
 
 #include <QMimeData>
 #include <QObject>
 #include <QStringList>
 
 #include <kaction.h>
-#include <kicon.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kactioncollection.h>
 #include <kxmlguifactory.h>
-#include <kabc/addressee.h>
-#include <kabc/vcardconverter.h>
 #include <kio/netaccess.h>
 #include <kmimetype.h>
 #include <kio/job.h>
-#include <kdebug.h>
+
+#ifdef PLAN_KDEPIMLIBS_FOUND
+#include <kabc/addressee.h>
+#include <kabc/vcardconverter.h>
+#endif
+
 
 namespace KPlato
 {
@@ -80,20 +85,26 @@ int ResourceModel::propertyCount() const
 
 QVariant ResourceModel::name( const Resource *res, int role ) const
 {
-    //kDebug()<<res->name()<<","<<role;
+    //kDebug(planDbg())<<res->name()<<","<<role;
     switch ( role ) {
         case Qt::DisplayRole:
         case Qt::EditRole:
+            return res->name();
         case Qt::ToolTipRole:
+            if ( res->autoAllocate() ) {
+                return i18nc( "@info:tooltip", "%1:<nl/>This resource will be automatically allocated to new tasks", res->name() );
+            }
             return res->name();
         case Qt::StatusTipRole:
         case Qt::WhatsThisRole:
             return QVariant();
         case Qt::DecorationRole:
             if ( res->isBaselined() ) {
-                return KIcon( "view-time-schedule-baselined" );
+                return koIcon("view-time-schedule-baselined");
              }
              break;
+        case Qt::CheckStateRole:
+            return res->autoAllocate() ? Qt::Checked : Qt::Unchecked;
         default:
             break;
     }
@@ -102,7 +113,7 @@ QVariant ResourceModel::name( const Resource *res, int role ) const
 
 QVariant ResourceModel::name( const  ResourceGroup *res, int role ) const
 {
-    //kDebug()<<res->name()<<","<<role;
+    //kDebug(planDbg())<<res->name()<<","<<role;
     switch ( role ) {
         case Qt::DisplayRole:
         case Qt::EditRole:
@@ -397,7 +408,7 @@ QVariant ResourceModel::data( const Resource *resource, int property, int role )
         case ResourceOvertimeRate: result = overtimeRate( resource, role ); break;
         case ResourceAccount: result = account( resource, role ); break;
         default:
-            kDebug()<<"data: invalid display value: property="<<property;
+            kDebug(planDbg())<<"data: invalid display value: property="<<property;
             break;
     }
     return result;
@@ -420,7 +431,7 @@ QVariant ResourceModel::data( const ResourceGroup *group, int property, int role
                 if ( property < propertyCount() ) {
                     result = "";
                 } else {
-                    kDebug()<<"data: invalid display value column"<<property;;
+                    kDebug(planDbg())<<"data: invalid display value column"<<property;;
                     return QVariant();
                 }
             }
@@ -502,7 +513,7 @@ ResourceItemModel::~ResourceItemModel()
 
 void ResourceItemModel::slotResourceToBeInserted( const ResourceGroup *group, int row )
 {
-    //kDebug()<<group->name()<<","<<row;
+    //kDebug(planDbg())<<group->name()<<","<<row;
     Q_ASSERT( m_group == 0 );
     m_group = const_cast<ResourceGroup*>(group);
     beginInsertRows( index( group ), row, row );
@@ -510,7 +521,7 @@ void ResourceItemModel::slotResourceToBeInserted( const ResourceGroup *group, in
 
 void ResourceItemModel::slotResourceInserted( const Resource *resource )
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     Q_ASSERT( resource->parentGroup() == m_group );
 #ifdef NDEBUG
     Q_UNUSED(resource)
@@ -522,7 +533,7 @@ void ResourceItemModel::slotResourceInserted( const Resource *resource )
 
 void ResourceItemModel::slotResourceToBeRemoved( const Resource *resource )
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     Q_ASSERT( m_resource == 0 );
 #ifdef NDEBUG
     Q_UNUSED(resource)
@@ -534,7 +545,7 @@ void ResourceItemModel::slotResourceToBeRemoved( const Resource *resource )
 
 void ResourceItemModel::slotResourceRemoved( const Resource *resource )
 {
-    //kDebug()<<resource->name();
+    //kDebug(planDbg())<<resource->name();
     Q_ASSERT( resource == m_resource );
 #ifdef NDEBUG
     Q_UNUSED(resource)
@@ -545,7 +556,7 @@ void ResourceItemModel::slotResourceRemoved( const Resource *resource )
 
 void ResourceItemModel::slotResourceGroupToBeInserted( const ResourceGroup *group, int row )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     Q_ASSERT( m_group == 0 );
     m_group = const_cast<ResourceGroup*>(group);
     beginInsertRows( QModelIndex(), row, row );
@@ -553,7 +564,7 @@ void ResourceItemModel::slotResourceGroupToBeInserted( const ResourceGroup *grou
 
 void ResourceItemModel::slotResourceGroupInserted( const ResourceGroup *group )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     Q_ASSERT( group == m_group );
 #ifdef NDEBUG
     Q_UNUSED(group)
@@ -564,7 +575,7 @@ void ResourceItemModel::slotResourceGroupInserted( const ResourceGroup *group )
 
 void ResourceItemModel::slotResourceGroupToBeRemoved( const ResourceGroup *group )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     Q_ASSERT( m_group == 0 );
     m_group = const_cast<ResourceGroup*>(group);
     int row = index( group ).row();
@@ -573,7 +584,7 @@ void ResourceItemModel::slotResourceGroupToBeRemoved( const ResourceGroup *group
 
 void ResourceItemModel::slotResourceGroupRemoved( const ResourceGroup *group )
 {
-    //kDebug()<<group->name();
+    //kDebug(planDbg())<<group->name();
     Q_ASSERT( group == m_group );
 #ifdef NDEBUG
     Q_UNUSED(group)
@@ -646,11 +657,11 @@ Qt::ItemFlags ResourceItemModel::flags( const QModelIndex &index ) const
 {
     Qt::ItemFlags flags = ItemModelBase::flags( index );
     if ( !m_readWrite ) {
-        //kDebug()<<"read only"<<flags;
+        //kDebug(planDbg())<<"read only"<<flags;
         return flags &= ~Qt::ItemIsEditable;
     }
     if ( !index.isValid() ) {
-        //kDebug()<<"invalid"<<flags;
+        //kDebug(planDbg())<<"invalid"<<flags;
         return flags;
     }
     Resource *r = qobject_cast<Resource*>( object ( index ) );
@@ -658,7 +669,7 @@ Qt::ItemFlags ResourceItemModel::flags( const QModelIndex &index ) const
         flags |= Qt::ItemIsDragEnabled;
         switch ( index.column() ) {
             case ResourceModel::ResourceName:
-                flags |= Qt::ItemIsEditable;
+                flags |= Qt::ItemIsEditable | Qt::ItemIsUserCheckable;
                 break;
             case ResourceModel::ResourceType:
                 if ( ! r->isBaselined() ) {
@@ -683,7 +694,7 @@ Qt::ItemFlags ResourceItemModel::flags( const QModelIndex &index ) const
             default:
                 flags |= Qt::ItemIsEditable;
         }
-        //kDebug()<<"resource"<<flags;
+        //kDebug(planDbg())<<"resource"<<flags;
     } else if ( qobject_cast<ResourceGroup*>( object( index ) ) ) {
         flags |= Qt::ItemIsDropEnabled;
         switch ( index.column() ) {
@@ -691,7 +702,7 @@ Qt::ItemFlags ResourceItemModel::flags( const QModelIndex &index ) const
             case ResourceModel::ResourceType: flags |= Qt::ItemIsEditable; break;
             default: flags &= ~Qt::ItemIsEditable;
         }
-        //kDebug()<<"group"<<flags;
+        //kDebug(planDbg())<<"group"<<flags;
     }
     return flags;
 }
@@ -702,7 +713,7 @@ QModelIndex ResourceItemModel::parent( const QModelIndex &index ) const
     if ( !index.isValid() || m_project == 0 ) {
         return QModelIndex();
     }
-    //kDebug()<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
+    //kDebug(planDbg())<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
 
     Resource *r = qobject_cast<Resource*>( object( index ) );
     if ( r && r->parentGroup() ) {
@@ -785,13 +796,12 @@ int ResourceItemModel::rowCount( const QModelIndex &parent ) const
 
 QVariant ResourceItemModel::name( const  ResourceGroup *res, int role ) const
 {
-    //kDebug()<<res->name()<<","<<role;
+    //kDebug(planDbg())<<res->name()<<","<<role;
     switch ( role ) {
         case Qt::DisplayRole:
         case Qt::EditRole:
         case Qt::ToolTipRole:
             return res->name();
-            break;
         case Qt::StatusTipRole:
         case Qt::WhatsThisRole:
             return QVariant();
@@ -806,7 +816,10 @@ bool ResourceItemModel::setName( Resource *res, const QVariant &value, int role
             if ( value.toString() == res->name() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceNameCmd( res, value.toString(), "Modify resource name" ) );
+            emit executeCommand( new ModifyResourceNameCmd( res, value.toString(), i18nc( "(qtundo-format)", "Modify resource name" ) ) );
+            return true;
+        case Qt::CheckStateRole:
+            emit executeCommand( new ModifyResourceAutoAllocateCmd( res, value.toBool(), i18nc( "(qtundo-format)", "Modify resource auto allocate" ) ) );
             return true;
     }
     return false;
@@ -819,7 +832,7 @@ bool ResourceItemModel::setName( ResourceGroup *res, const QVariant &value, int
             if ( value.toString() == res->name() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceGroupNameCmd( res, value.toString(), "Modify resourcegroup name" ) );
+            emit executeCommand( new ModifyResourceGroupNameCmd( res, value.toString(), i18nc( "(qtundo-format)", "Modify resourcegroup name" ) ) );
             return true;
     }
     return false;
@@ -860,7 +873,7 @@ bool ResourceItemModel::setType( Resource *res, const QVariant &value, int role
             if ( v == res->type() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceTypeCmd( res, v, "Modify resource type" ) );
+            emit executeCommand( new ModifyResourceTypeCmd( res, v, i18nc( "(qtundo-format)", "Modify resource type" ) ) );
             return true;
         }
     }
@@ -881,7 +894,7 @@ bool ResourceItemModel::setType( ResourceGroup *res, const QVariant &value, int
             if ( v == res->type() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceGroupTypeCmd( res, v, "Modify resourcegroup type" ) );
+            emit executeCommand( new ModifyResourceGroupTypeCmd( res, v, i18nc( "(qtundo-format)", "Modify resourcegroup type" ) ) );
             return true;
         }
     }
@@ -895,7 +908,7 @@ bool ResourceItemModel::setInitials( Resource *res, const QVariant &value, int r
             if ( value.toString() == res->initials() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceInitialsCmd( res, value.toString(), "Modify resource initials" ) );
+            emit executeCommand( new ModifyResourceInitialsCmd( res, value.toString(), i18nc( "(qtundo-format)", "Modify resource initials" ) ) );
             return true;
     }
     return false;
@@ -908,7 +921,7 @@ bool ResourceItemModel::setEmail( Resource *res, const QVariant &value, int role
             if ( value.toString() == res->email() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceEmailCmd( res, value.toString(), "Modify resource email" ) );
+            emit executeCommand( new ModifyResourceEmailCmd( res, value.toString(), i18nc( "(qtundo-format)", "Modify resource email" ) ) );
             return true;
     }
     return false;
@@ -929,7 +942,7 @@ bool ResourceItemModel::setCalendar( Resource *res, const QVariant &value, int r
             if ( c == res->calendar( true ) ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceCalendarCmd( res, c, "Modify resource calendar" ) );
+            emit executeCommand( new ModifyResourceCalendarCmd( res, c, i18nc( "(qtundo-format)", "Modify resource calendar" ) ) );
             return true;
         }
     }
@@ -944,7 +957,7 @@ bool ResourceItemModel::setUnits( Resource *res, const QVariant &value, int role
             if ( value.toInt() == res->units() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceUnitsCmd( res, value.toInt(), "Modify resource available units" ) );
+            emit executeCommand( new ModifyResourceUnitsCmd( res, value.toInt(), i18nc( "(qtundo-format)", "Modify resource available units" ) ) );
             return true;
     }
     return false;
@@ -957,7 +970,7 @@ bool ResourceItemModel::setAvailableFrom( Resource *res, const QVariant &value,
             if ( value.toDateTime() == res->availableFrom() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceAvailableFromCmd( res, value.toDateTime(), "Modify resource available from" ) );
+            emit executeCommand( new ModifyResourceAvailableFromCmd( res, value.toDateTime(), i18nc( "(qtundo-format)", "Modify resource available from" ) ) );
             return true;
     }
     return false;
@@ -970,7 +983,7 @@ bool ResourceItemModel::setAvailableUntil( Resource *res, const QVariant &value,
             if ( value.toDateTime() == res->availableUntil() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceAvailableUntilCmd( res, value.toDateTime(), "Modify resource available until" ) );
+            emit executeCommand( new ModifyResourceAvailableUntilCmd( res, value.toDateTime(), i18nc( "(qtundo-format)", "Modify resource available until" ) ) );
             return true;
     }
     return false;
@@ -983,7 +996,7 @@ bool ResourceItemModel::setNormalRate( Resource *res, const QVariant &value, int
             if ( value.toDouble() == res->normalRate() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceNormalRateCmd( res, value.toDouble(), "Modify resource normal rate" ) );
+            emit executeCommand( new ModifyResourceNormalRateCmd( res, value.toDouble(), i18nc( "(qtundo-format)", "Modify resource normal rate" ) ) );
             return true;
     }
     return false;
@@ -996,7 +1009,7 @@ bool ResourceItemModel::setOvertimeRate( Resource *res, const QVariant &value, i
             if ( value.toDouble() == res->overtimeRate() ) {
                 return false;
             }
-            emit executeCommand( new ModifyResourceOvertimeRateCmd( res, value.toDouble(), "Modify resource overtime rate" ) );
+            emit executeCommand( new ModifyResourceOvertimeRateCmd( res, value.toDouble(), i18nc( "(qtundo-format)", "Modify resource overtime rate" ) ) );
             return true;
     }
     return false;
@@ -1016,9 +1029,6 @@ bool ResourceItemModel::setAccount( Resource *res, const QVariant &value, int ro
             } else if ( value.type() == QVariant::String ) {
                 a = m_project->accounts().findAccount( value.toString() );
             }
-            if ( a == 0 ) {
-                return false;
-            }
             Account *old = res->account();
             if ( old != a ) {
                 emit executeCommand( new ResourceModifyAccountCmd( *res, old, a, i18nc( "(qtundo-format)", "Modify resource account" ) ) );
@@ -1075,7 +1085,7 @@ bool ResourceItemModel::setData( const QModelIndex &index, const QVariant &value
     if ( ! index.isValid() ) {
         return ItemModelBase::setData( index, value, role );
     }
-    if ( ( flags( index ) &Qt::ItemIsEditable ) == 0 || role != Qt::EditRole ) {
+    if ( ( flags( index ) &Qt::ItemIsEditable ) == 0 ||  ! ( role == Qt::EditRole || role == Qt::CheckStateRole ) ) {
         return false;
     }
     QObject *obj = object( index );
@@ -1148,6 +1158,11 @@ QObject *ResourceItemModel::object( const QModelIndex &index ) const
     return o;
 }
 
+ResourceGroup *ResourceItemModel::group( const QModelIndex &index ) const
+{
+    return qobject_cast<ResourceGroup*>( object( index ) );
+}
+
 Resource *ResourceItemModel::resource( const QModelIndex &index ) const
 {
     return qobject_cast<Resource*>( object( index ) );
@@ -1188,9 +1203,9 @@ Qt::DropActions ResourceItemModel::supportedDropActions() const
 
 bool ResourceItemModel::dropAllowed( const QModelIndex &index, int dropIndicatorPosition, const QMimeData *data )
 {
-//     kDebug()<<index<<data;
     Q_UNUSED(data);
-    //kDebug()<<index;
+
+    //kDebug(planDbg())<<index<<data;
     // TODO: if internal, don't allow dropping on my own parent
     switch ( dropIndicatorPosition ) {
         case ItemModelBase::OnItem:
@@ -1204,9 +1219,11 @@ bool ResourceItemModel::dropAllowed( const QModelIndex &index, int dropIndicator
 QStringList ResourceItemModel::mimeTypes() const
 {
     return QStringList()
+#ifdef PLAN_KDEPIMLIBS_FOUND
             << "text/x-vcard"
             << "text/directory"
             << "text/uri-list"
+#endif
             << "application/x-vnd.kde.plan.resourceitemmodel.internal";
 }
 
@@ -1220,7 +1237,7 @@ void ResourceItemModel::slotDataArrived( KIO::Job *job, const QByteArray &data
 void ResourceItemModel::slotJobFinished( KJob *job )
 {
     if ( job->error() || ! m_dropDataMap.contains( job ) ) {
-        kDebug()<<(job->error() ? "Job error":"Error: no such job");
+        kDebug(planDbg())<<(job->error() ? "Job error":"Error: no such job");
     } else if ( KMimeType::findByContent( m_dropDataMap[ job ].data )->is( "text/x-vcard" ) ) {
         ResourceGroup *g = 0;
         if ( m_dropDataMap[ job ].parent.isValid() ) {
@@ -1229,7 +1246,7 @@ void ResourceItemModel::slotJobFinished( KJob *job )
             g = qobject_cast<ResourceGroup*>( object( index( m_dropDataMap[ job ].row, m_dropDataMap[ job ].column, m_dropDataMap[ job ].parent ) ) );
         }
         if ( g == 0 ) {
-            kDebug()<<"No group"<<m_dropDataMap[ job ].row<<m_dropDataMap[ job ].column<<m_dropDataMap[ job ].parent;
+            kDebug(planDbg())<<"No group"<<m_dropDataMap[ job ].row<<m_dropDataMap[ job ].column<<m_dropDataMap[ job ].parent;
         } else {
             createResources( g, m_dropDataMap[ job ].data );
         }
@@ -1243,6 +1260,7 @@ void ResourceItemModel::slotJobFinished( KJob *job )
 
 bool ResourceItemModel::createResources( ResourceGroup *group, const QByteArray &data )
 {
+#ifdef PLAN_KDEPIMLIBS_FOUND
     KABC::VCardConverter vc;
     KABC::Addressee::List lst = vc.parseVCards( data );
     MacroCommand *m = new MacroCommand( i18ncp( "(qtundo-format)", "Add resource from address book", "Add %1 resources from address book", lst.count() ) );
@@ -1262,11 +1280,14 @@ bool ResourceItemModel::createResources( ResourceGroup *group, const QByteArray
     }
     emit executeCommand( m );
     return true;
+#else
+    return false;
+#endif
 }
 
 bool ResourceItemModel::dropMimeData( const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent )
 {
-    kDebug()<<row<<column<<parent;
+    kDebug(planDbg())<<row<<column<<parent;
     if (action == Qt::IgnoreAction) {
         return true;
     }
@@ -1280,12 +1301,12 @@ bool ResourceItemModel::dropMimeData( const QMimeData *data, Qt::DropAction acti
         g = qobject_cast<ResourceGroup*>( object( index( row, column, parent ) ) );
     }
     if ( g == 0 ) {
-        kDebug()<<"No group"<<row<<column<<parent;
+        kDebug(planDbg())<<"No group"<<row<<column<<parent;
         return false;
     }
-    kDebug()<<data->formats()<<g->name();
+    kDebug(planDbg())<<data->formats()<<g->name();
     if ( data->hasFormat( "application/x-vnd.kde.plan.resourceitemmodel.internal" ) ) {
-        kDebug()<<action<<Qt::MoveAction;
+        kDebug(planDbg())<<action<<Qt::MoveAction;
         if ( action == Qt::MoveAction ) {
             MacroCommand *m = 0;
             QByteArray encodedData = data->data( "application/x-vnd.kde.plan.resourceitemmodel.internal" );
@@ -1343,7 +1364,7 @@ bool ResourceItemModel::dropMimeData( const QMimeData *data, Qt::DropAction acti
         bool result = false;
         foreach ( const KUrl &url, urls ) {
             if ( url.protocol() != "akonadi" || ! KIO::NetAccess::exists( url, KIO::NetAccess::SourceSide, 0 ) ) {
-                kDebug()<<url<<"is not 'akonadi' or does not exist";
+                kDebug(planDbg())<<url<<"is not 'akonadi' or does not exist";
                 continue;
             }
             KIO::TransferJob *job = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
@@ -1377,7 +1398,7 @@ QList<Resource*> ResourceItemModel::resourceList( QDataStream &stream )
             lst << r;
         }
     }
-    kDebug()<<lst;
+    kDebug(planDbg())<<lst;
     return lst;
 }
 
@@ -1389,7 +1410,7 @@ QMimeData *ResourceItemModel::mimeData( const QModelIndexList & indexes ) const
     QList<int> rows;
     foreach (const QModelIndex &index, indexes) {
         if ( index.isValid() && !rows.contains( index.row() ) ) {
-            //kDebug()<<index.row();
+            //kDebug(planDbg())<<index.row();
             Resource *r = ::qobject_cast<Resource*>( object( index ) );
             if ( r ) {
                 rows << index.row();
@@ -1410,7 +1431,7 @@ QMimeData *ResourceItemModel::mimeData( const QModelIndexList & indexes ) const
 
 QModelIndex ResourceItemModel::insertGroup( ResourceGroup *g )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit executeCommand( new AddResourceGroupCmd( m_project, g, i18nc( "(qtundo-format)", "Add resource group" ) ) );
     int row = m_project->resourceGroups().indexOf( g );
     if ( row != -1 ) {
@@ -1421,7 +1442,7 @@ QModelIndex ResourceItemModel::insertGroup( ResourceGroup *g )
 
 QModelIndex ResourceItemModel::insertResource( ResourceGroup *g, Resource *r, Resource * /*after*/ )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit executeCommand( new AddResourceCmd( g, r, i18nc( "(qtundo-format)", "Add resource" ) ) );
     int row = g->indexOf( r );
     if ( row != -1 ) {
@@ -1430,6 +1451,19 @@ QModelIndex ResourceItemModel::insertResource( ResourceGroup *g, Resource *r, Re
     return QModelIndex();
 }
 
+int ResourceItemModel::sortRole( int column ) const
+{
+    switch ( column ) {
+        case ResourceModel::ResourceAvailableFrom:
+        case ResourceModel::ResourceAvailableUntil:
+            return Qt::EditRole;
+        default:
+            break;
+    }
+    return Qt::DisplayRole;
+}
+
+
 //-------------------
 ResourceItemSFModel::ResourceItemSFModel( QObject *parent )
     : QSortFilterProxyModel( parent )
@@ -1481,6 +1515,217 @@ bool ResourceItemSFModel::filterAcceptsRow( int source_row, const QModelIndex &
     return ! m_filteredResources.contains( m->resource( idx ) );
 }
 
+//-----------------------
+AllocatedResourceItemModel::AllocatedResourceItemModel( QObject *parent )
+    : QSortFilterProxyModel( parent ),
+    m_task( 0 )
+{
+    setDynamicSortFilter( true );
+    setSourceModel( new ResourceItemModel( this ) );
+}
+
+int AllocatedResourceItemModel::columnCount( const QModelIndex &idx ) const
+{
+    return 2;
+}
+
+Project *AllocatedResourceItemModel::project() const
+{
+    return static_cast<ResourceItemModel*>( sourceModel() )->project();
+}
+
+void AllocatedResourceItemModel::setProject( Project *project )
+{
+    kDebug(planDbg())<<this->project()<<"="<<project;
+    Project *p =this->project();
+    if ( p ) {
+        disconnect(p, SIGNAL(nodeChanged(Node*)), this, SLOT(slotNodeChanged(Node*)));
+    }
+    static_cast<ResourceItemModel*>( sourceModel() )->setProject( project );
+    if ( project ) {
+        connect(project, SIGNAL(nodeChanged(Node*)), this, SLOT(slotNodeChanged(Node*)));
+    }
+    kDebug(planDbg())<<rowCount()<<":"<<sourceModel()->rowCount();
+}
+
+void AllocatedResourceItemModel::reset()
+{
+    QSortFilterProxyModel::reset();
+    emit expandAll();
+    emit resizeColumnToContents( 0 );
+}
+
+void AllocatedResourceItemModel::slotNodeChanged( Node *n )
+{
+    kDebug(planDbg())<<(n==m_task)<<n<<n->name();
+    if ( n != m_task ) {
+        return;
+    }
+    reset();
+}
+
+Task *AllocatedResourceItemModel::task() const
+{
+    return m_task;
+}
+
+void AllocatedResourceItemModel::setTask( Task *task )
+{
+    kDebug(planDbg())<<m_task<<"="<<task<<(task?task->name():"");
+    m_task = task;
+    reset();
+    kDebug(planDbg())<<rowCount()<<":"<<sourceModel()->rowCount();
+}
+
+QObject* AllocatedResourceItemModel::object(const QModelIndex& idx) const
+{
+    return static_cast<ResourceItemModel*>( sourceModel() )->object( mapToSource( idx ) );
+}
+
+Resource *AllocatedResourceItemModel::resource( const QModelIndex &idx ) const
+{
+    return qobject_cast<Resource*>( object( idx ) );
+}
+
+QModelIndex AllocatedResourceItemModel::index( Resource *r ) const
+{
+    return mapFromSource( static_cast<ResourceItemModel*>( sourceModel() )->index( r ) );
+}
+
+Qt::ItemFlags AllocatedResourceItemModel::flags( const QModelIndex & index ) const
+{
+    Qt::ItemFlags f = QSortFilterProxyModel::flags( index );
+    f &= ~Qt::ItemIsUserCheckable;
+    return f;
+}
+
+QVariant AllocatedResourceItemModel::headerData(int section, Qt::Orientation orientation, int role) const
+{
+    if ( section == 1 ) {
+        if ( orientation == Qt::Horizontal && role == Qt::DisplayRole ) {
+            return i18nc( "@title:column", "Allocation" );
+        }
+        return QVariant();
+    }
+    return QSortFilterProxyModel::headerData( section, orientation, role );
+}
+
+QVariant AllocatedResourceItemModel::allocation( const Resource *res, int role ) const
+{
+    ResourceRequest *rr = m_task->requests().find( res );
+    ResourceGroupRequest *gr = m_task->requests().find( res->parentGroup() );
+    if ( rr == 0 || gr == 0 ) {
+        return QVariant();
+    }
+    switch ( role ) {
+        case Qt::DisplayRole: {
+        case Qt::EditRole:
+            // xgettext: no-c-format
+            return i18nc( "<value>%", "%1%",rr->units() );
+        }
+        case Qt::ToolTipRole: {
+            if ( rr->units() == 0 ) {
+                return i18nc( "@info:tooltip", "Not allocated" );
+            }
+            return i18nc( "@info:tooltip", "%1 allocated out of %2 available", gr->count(), res->parentGroup()->numResources() );
+        }
+        default:
+            break;
+    }
+    return QVariant();
+}
+
+QVariant AllocatedResourceItemModel::allocation( const ResourceGroup *res, int role ) const
+{
+    ResourceGroupRequest *gr = m_task->requests().find( res );
+    if ( gr == 0 ) {
+        return QVariant();
+    }
+    switch ( role ) {
+        case Qt::DisplayRole:
+        case Qt::EditRole:
+            return QString( "%1 (%2)" ).arg( gr->units() ).arg( gr->count() );
+        case Qt::ToolTipRole: {
+            QString s1 = i18ncp( "@info:tooltip",
+                                 "%1 resource requested for dynamic allocation",
+                                 "%1 resources requested for dynamic allocation",
+                                 gr->units() );
+            QString s2 = i18ncp( "@info:tooltip",
+                                 "%1 resource allocated",
+                                 "%1 resources allocated",
+                                 gr->count() );
+
+            return i18nc( "@info:tooltip", "%1<nl/>%2", s1, s2 );
+        }
+        case Qt::WhatsThisRole: {
+            return i18nc( "@info:whatsthis",
+                          "<title>Group allocations</title>"
+                          "<para>You can allocate a number of resources from a group and let"
+                          " the scheduler select from the available resources at the time of scheduling.</para>"
+                          " These dynamically allocated resources will be in addition to any resource you have allocated specifically." );
+        }
+        case Role::Minimum: {
+            return 0;
+        }
+        case Role::Maximum: {
+            return res->numResources() - gr->units();
+        }
+        default:
+            break;
+    }
+    return QVariant();
+}
+
+QVariant AllocatedResourceItemModel::data(const QModelIndex& idx, int role) const
+{
+    if ( m_task == 0 || role == Qt::CheckStateRole || role == Qt::DecorationRole ) {
+        return QVariant();
+    }
+    if ( idx.column() == 1 ) {
+        switch ( role ) {
+            case Qt::TextAlignmentRole:
+                return Qt::AlignLeft;
+            default: {
+                QObject *o = object( idx );
+                Resource *r = qobject_cast<Resource*>( o );
+                if ( r ) {
+                    return allocation( r, role );
+                }
+                ResourceGroup *g = qobject_cast<ResourceGroup*>( o );
+                if ( g ) {
+                    return allocation( g, role );
+                }
+                break;
+            }
+            return QVariant();
+        }
+    }
+    return QSortFilterProxyModel::data( idx, role );
+}
+
+bool AllocatedResourceItemModel::filterAcceptsRow( int source_row, const QModelIndex & source_parent ) const
+{
+    if ( m_task == 0 ) {
+        return false;
+    }
+    QModelIndex idx = sourceModel()->index( source_row, 0, source_parent );
+    if ( ! idx.isValid() ) {
+        return false;
+    }
+    bool result = false;
+    const ResourceRequestCollection &req = m_task->requests();
+    if ( source_parent.isValid() ) {
+        const Resource *r = static_cast<ResourceItemModel*>( sourceModel() )->resource( idx );
+        result = (bool) req.find( r );
+    } else {
+        const ResourceGroup *g = static_cast<ResourceItemModel*>( sourceModel() )->group( idx );
+        ResourceGroupRequest *gr = req.find( g );
+        result = (bool) gr && ( gr->units() > 0 || gr->count() > 0 );
+    }
+    kDebug(planDbg())<<result<<":"<<source_parent<<idx;
+    return result;
+}
+
 } // namespace KPlato
 
 #include "kptresourcemodel.moc"
