@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Dag Andersen danders@get2net>
+  Copyright (C) 2007, 2012 Dag Andersen danders@get2net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -31,6 +31,9 @@
 #include "kptschedule.h"
 #include "kptdatetime.h"
 #include "kptschedulerplugin.h"
+#include "kptdebug.h"
+
+#include <KoIcon.h>
 
 #include <QObject>
 #include <QStringList>
@@ -38,8 +41,7 @@
 
 #include <kglobal.h>
 #include <klocale.h>
-#include <KIcon>
-#include <kdebug.h>
+
 
 namespace KPlato
 {
@@ -80,7 +82,7 @@ ScheduleItemModel::~ScheduleItemModel()
 
 void ScheduleItemModel::slotScheduleManagerToBeInserted( const ScheduleManager *parent, int row )
 {
-    //kDebug()<<parent<<row;
+    //kDebug(planDbg())<<parent<<row;
     if ( m_flat ) {
         return; // handle in *Inserted();
     }
@@ -91,7 +93,7 @@ void ScheduleItemModel::slotScheduleManagerToBeInserted( const ScheduleManager *
 
 void ScheduleItemModel::slotScheduleManagerInserted( const ScheduleManager *manager )
 {
-    //kDebug()<<manager->name();
+    //kDebug(planDbg())<<manager->name();
     if ( m_flat ) {
         int row = m_project->allScheduleManagers().indexOf( const_cast<ScheduleManager*>( manager ) );
         Q_ASSERT( row >= 0 );
@@ -109,7 +111,7 @@ void ScheduleItemModel::slotScheduleManagerInserted( const ScheduleManager *mana
 
 void ScheduleItemModel::slotScheduleManagerToBeRemoved( const ScheduleManager *manager )
 {
-    //kDebug()<<manager->name();
+    //kDebug(planDbg())<<manager->name();
     if ( m_flat ) {
         int row = m_managerlist.indexOf( const_cast<ScheduleManager*>( manager ) );
         beginRemoveRows( QModelIndex(), row, row );
@@ -126,7 +128,7 @@ void ScheduleItemModel::slotScheduleManagerToBeRemoved( const ScheduleManager *m
 
 void ScheduleItemModel::slotScheduleManagerRemoved( const ScheduleManager *manager )
 {
-    //kDebug()<<manager->name();
+    //kDebug(planDbg())<<manager->name();
     if ( m_flat ) {
         endRemoveRows();
         return;
@@ -138,13 +140,13 @@ void ScheduleItemModel::slotScheduleManagerRemoved( const ScheduleManager *manag
 
 void ScheduleItemModel::slotScheduleManagerToBeMoved( const ScheduleManager *manager )
 {
-    //kDebug()<<this<<manager->name()<<"from"<<(manager->parentManager()?manager->parentManager()->name():"project");
+    //kDebug(planDbg())<<this<<manager->name()<<"from"<<(manager->parentManager()?manager->parentManager()->name():"project");
     slotScheduleManagerToBeRemoved( manager );
 }
 
 void ScheduleItemModel::slotScheduleManagerMoved( const ScheduleManager *manager, int index )
 {
-    //kDebug()<<this<<manager->name()<<"to"<<manager->parentManager()<<index;
+    //kDebug(planDbg())<<this<<manager->name()<<"to"<<manager->parentManager()<<index;
     slotScheduleManagerRemoved( manager );
     slotScheduleManagerToBeInserted( manager->parentManager(), index );
     slotScheduleManagerInserted( manager );
@@ -232,7 +234,7 @@ void ScheduleItemModel::slotManagerChanged( ScheduleManager *sch )
     }
 
     int r = sch->parentManager() ? sch->parentManager()->indexOf( sch ) : m_project->indexOf( sch );
-    //kDebug()<<sch<<":"<<r;
+    //kDebug(planDbg())<<sch<<":"<<r;
     emit dataChanged( createIndex( r, 0, sch ), createIndex( r, columnCount() - 1, sch ) );
 }
 
@@ -273,6 +275,11 @@ Qt::ItemFlags ScheduleItemModel::flags( const QModelIndex &index ) const
                 break;
             case ScheduleModel::SchedulePlannedStart: break;
             case ScheduleModel::SchedulePlannedFinish: break;
+            case ScheduleModel::ScheduleGranularity:
+                if ( ! sm->supportedGranularities().isEmpty() ) {
+                    flags |= Qt::ItemIsEditable;
+                }
+                break;
             default: flags |= Qt::ItemIsEditable; break;
         }
         return flags;
@@ -286,7 +293,7 @@ QModelIndex ScheduleItemModel::parent( const QModelIndex &inx ) const
     if ( !inx.isValid() || m_project == 0 || m_flat ) {
         return QModelIndex();
     }
-    //kDebug()<<inx.internalPointer()<<":"<<inx.row()<<","<<inx.column();
+    //kDebug(planDbg())<<inx.internalPointer()<<":"<<inx.row()<<","<<inx.column();
     ScheduleManager *sm = manager( inx );
     if ( sm == 0 ) {
         return QModelIndex();
@@ -296,9 +303,9 @@ QModelIndex ScheduleItemModel::parent( const QModelIndex &inx ) const
 
 QModelIndex ScheduleItemModel::index( int row, int column, const QModelIndex &parent ) const
 {
-    //kDebug()<<m_project<<":"<<row<<","<<column;
+    //kDebug(planDbg())<<m_project<<":"<<row<<","<<column;
     if ( m_project == 0 || column < 0 || column >= columnCount() || row < 0 || row >= rowCount( parent ) ) {
-        //kDebug()<<row<<","<<column<<" out of bounce";
+        //kDebug(planDbg())<<row<<","<<column<<" out of bounce";
         return QModelIndex();
     }
     if ( m_flat ) {
@@ -344,7 +351,7 @@ int ScheduleItemModel::rowCount( const QModelIndex &parent ) const
     }
     ScheduleManager *sm = manager( parent );
     if ( sm ) {
-        //kDebug()<<sm->name()<<","<<sm->children().count();
+        //kDebug(planDbg())<<sm->name()<<","<<sm->children().count();
         return sm->children().count();
     }
     return 0;
@@ -366,7 +373,7 @@ QVariant ScheduleItemModel::name( const QModelIndex &index, int role ) const
             return QVariant();
         case Qt::DecorationRole:
             if ( sm->isBaselined() ) {
-                return KIcon( "view-time-schedule-baselined" );
+                return koIcon("view-time-schedule-baselined");
             }
             return QVariant();
         default:
@@ -760,9 +767,67 @@ QVariant ScheduleItemModel::isScheduled( const QModelIndex &index, int role ) co
     return QVariant();
 }
 
+QVariant ScheduleItemModel::granularity(const QModelIndex &index, int role) const
+{
+    ScheduleManager *sm = manager( index );
+    if ( sm == 0 ) {
+        return QVariant();
+    }
+    switch ( role ) {
+        case Qt::EditRole:
+        case Role::EnumListValue:
+            return qMin( sm->granularity(), sm->supportedGranularities().count() - 1 );
+        case Qt::DisplayRole: {
+            QList<long unsigned int> lst = sm->supportedGranularities();
+            if ( lst.isEmpty() ) {
+                return i18nc( "Scheduling granularity not supported", "None" );
+            }
+            int idx = sm->granularity();
+            qulonglong g = idx < lst.count() ? lst[ idx ] : lst.last();
+            return KGlobal::locale()->formatDuration( g );
+        }
+        case Qt::ToolTipRole: {
+            QList<long unsigned int> lst = sm->supportedGranularities();
+            if ( lst.isEmpty() ) {
+                return i18nc( "@info:tooltip", "Scheduling granularity not supported" );
+            }
+            int idx = sm->granularity();
+            qulonglong g = idx < lst.count() ? lst[ idx ] : lst.last();
+            return i18nc( "@info:tooltip", "Selected scheduling granularity: %1", KGlobal::locale()->formatDuration( g ) );
+        }
+        case Qt::TextAlignmentRole:
+            return Qt::AlignRight;
+        case Qt::StatusTipRole:
+        case Qt::WhatsThisRole:
+            return QVariant();
+        case Role::EnumList: {
+            QStringList sl;
+            foreach ( long unsigned int v, sm->supportedGranularities() ) {
+                sl << KGlobal::locale()->formatDuration( v );
+            }
+            return sl;
+        }
+    }
+    return QVariant();
+}
+
+bool ScheduleItemModel::setGranularity( const QModelIndex &index, const QVariant &value, int role )
+{
+    ScheduleManager *sm = manager( index );
+    if ( sm != 0 ) {
+        switch ( role ) {
+            case Qt::EditRole: {
+                emit executeCommand( new ModifyScheduleManagerSchedulingGranularityCmd( *sm, value.toInt(), i18nc( "(qtundo-format)", "Modify scheduling granularity" ) ) );
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
 QVariant ScheduleItemModel::data( const QModelIndex &index, int role ) const
 {
-    //kDebug()<<index.row()<<","<<index.column();
+    //kDebug(planDbg())<<index.row()<<","<<index.column();
     QVariant result;
     if ( role == Qt::TextAlignmentRole ) {
         return headerData( index.column(), Qt::Horizontal, role );
@@ -776,9 +841,10 @@ QVariant ScheduleItemModel::data( const QModelIndex &index, int role ) const
         case ScheduleModel::SchedulePlannedStart: result = projectStart(  index, role ); break;
         case ScheduleModel::SchedulePlannedFinish: result = projectEnd( index, role ); break;
         case ScheduleModel::ScheduleScheduler: result = scheduler( index, role ); break;
+        case ScheduleModel::ScheduleGranularity: result = granularity( index, role ); break;
         case ScheduleModel::ScheduleScheduled: result = isScheduled( index, role ); break;
         default:
-            kDebug()<<"data: invalid display value column"<<index.column();
+            kDebug(planDbg())<<"data: invalid display value column"<<index.column();
             return QVariant();
     }
     if ( result.isValid() ) {
@@ -809,6 +875,7 @@ bool ScheduleItemModel::setData( const QModelIndex &index, const QVariant &value
         case ScheduleModel::SchedulePlannedStart: return false;
         case ScheduleModel::SchedulePlannedFinish: return false;
         case ScheduleModel::ScheduleScheduler: return setScheduler( index, value, role ); break;
+        case ScheduleModel::ScheduleGranularity: return setGranularity( index, value, role );
         case ScheduleModel::ScheduleScheduled: break;
         default:
             qWarning("data: invalid display value column %d", index.column());
@@ -831,6 +898,7 @@ QVariant ScheduleItemModel::headerData( int section, Qt::Orientation orientation
                 case ScheduleModel::SchedulePlannedStart: return i18n( "Planned Start" );
                 case ScheduleModel::SchedulePlannedFinish: return i18n( "Planned Finish" );
                 case ScheduleModel::ScheduleScheduler: return i18n( "Scheduler" );
+                case ScheduleModel::ScheduleGranularity: return i18nc( "title:column", "Granularity" );
                 case ScheduleModel::ScheduleScheduled: return i18n( "Scheduled" );
                 default: return QVariant();
             }
@@ -849,6 +917,7 @@ QVariant ScheduleItemModel::headerData( int section, Qt::Orientation orientation
             case ScheduleModel::SchedulePlannedStart: return ToolTip::scheduleStart();
             case ScheduleModel::SchedulePlannedFinish: return ToolTip::scheduleFinish();
             case ScheduleModel::ScheduleScheduler: return ToolTip::scheduleScheduler();
+            case ScheduleModel::ScheduleGranularity: return ToolTip::scheduleGranularity();
             case ScheduleModel::ScheduleScheduled: return QVariant();
             default: return QVariant();
         }
@@ -872,7 +941,7 @@ QAbstractItemDelegate *ScheduleItemModel::createDelegate( int column, QWidget *p
         case ScheduleModel::ScheduleDirection: return new EnumDelegate( parent );
         case ScheduleModel::ScheduleOverbooking: return new EnumDelegate( parent );
         case ScheduleModel::ScheduleDistribution: return new EnumDelegate( parent );
-//        case ScheduleModel::ScheduleCalculate: return new EnumDelegate( parent );
+        case ScheduleModel::ScheduleGranularity: return new EnumDelegate( parent );
         case ScheduleModel::ScheduleScheduler: return new EnumDelegate( parent );
     }
     return 0;
@@ -953,7 +1022,7 @@ void ScheduleLogItemModel::slotScheduleManagerToBeRemoved( const ScheduleManager
 
 void ScheduleLogItemModel::slotScheduleManagerRemoved( const ScheduleManager *manager )
 {
-    kDebug()<<manager->name();
+    kDebug(planDbg())<<manager->name();
 }
 
 void ScheduleLogItemModel::slotScheduleToBeInserted( const ScheduleManager *manager, int row )
@@ -967,7 +1036,7 @@ void ScheduleLogItemModel::slotScheduleToBeInserted( const ScheduleManager *mana
 //FIXME remove const on MainSchedule
 void ScheduleLogItemModel::slotScheduleInserted( const MainSchedule *sch )
 {
-    kDebug()<<m_schedule<<sch;
+    kDebug(planDbg())<<m_schedule<<sch;
     if ( m_manager && m_manager == sch->manager() && sch == m_manager->expected() ) {
         m_schedule = const_cast<MainSchedule*>( sch );
         refresh();
@@ -976,7 +1045,7 @@ void ScheduleLogItemModel::slotScheduleInserted( const MainSchedule *sch )
 
 void ScheduleLogItemModel::slotScheduleToBeRemoved( const MainSchedule *sch )
 {
-    kDebug()<<m_schedule<<sch;
+    kDebug(planDbg())<<m_schedule<<sch;
     if ( m_schedule == sch ) {
         m_schedule = 0;
         clear();
@@ -985,12 +1054,12 @@ void ScheduleLogItemModel::slotScheduleToBeRemoved( const MainSchedule *sch )
 
 void ScheduleLogItemModel::slotScheduleRemoved( const MainSchedule *sch )
 {
-    kDebug()<<m_schedule<<sch;
+    kDebug(planDbg())<<m_schedule<<sch;
 }
 
 void ScheduleLogItemModel::setProject( Project *project )
 {
-    kDebug()<<m_project<<"->"<<project;
+    kDebug(planDbg())<<m_project<<"->"<<project;
     if ( m_project ) {
         disconnect( m_project, SIGNAL( scheduleManagerChanged( ScheduleManager* ) ), this, SLOT( slotManagerChanged( ScheduleManager* ) ) );
 
@@ -1030,7 +1099,7 @@ void ScheduleLogItemModel::setProject( Project *project )
 
 void ScheduleLogItemModel::setManager( ScheduleManager *manager )
 {
-    kDebug()<<m_manager<<"->"<<manager;
+    kDebug(planDbg())<<m_manager<<"->"<<manager;
     if ( manager != m_manager ) {
         if ( m_manager ) {
             disconnect( m_manager, SIGNAL(logInserted(MainSchedule*, int, int)), this, SLOT(slotLogInserted(MainSchedule*, int, int)));
@@ -1056,7 +1125,7 @@ void ScheduleLogItemModel::slotLogInserted( MainSchedule *s, int firstrow, int l
 //FIXME: This only add logs (insert is not used atm)
 void ScheduleLogItemModel::addLogEntry( const Schedule::Log &log, int /*row*/ )
 {
-//     kDebug()<<log;
+//     kDebug(planDbg())<<log;
     QList<QStandardItem*> lst;
     if ( log.resource ) {
         lst.append( new QStandardItem( log.resource->name() ) );
@@ -1093,7 +1162,7 @@ void ScheduleLogItemModel::addLogEntry( const Schedule::Log &log, int /*row*/ )
         }
     }
     appendRow( lst );
-//     kDebug()<<"added:"<<row<<rowCount()<<columnCount();
+//     kDebug(planDbg())<<"added:"<<row<<rowCount()<<columnCount();
 }
 
 void ScheduleLogItemModel::refresh()
@@ -1104,10 +1173,10 @@ void ScheduleLogItemModel::refresh()
     setHorizontalHeaderLabels( lst );
 
     if ( m_schedule == 0 ) {
-        kDebug()<<"No main schedule";
+        kDebug(planDbg())<<"No main schedule";
         return;
     }
-//     kDebug()<<m_schedule<<m_schedule->logs().count();
+//     kDebug(planDbg())<<m_schedule<<m_schedule->logs().count();
     int i = 1;
     foreach ( const Schedule::Log &l, m_schedule->logs() ) {
         addLogEntry( l, i++ );
@@ -1122,7 +1191,7 @@ QString ScheduleLogItemModel::identity( const QModelIndex &idx ) const
 
 void ScheduleLogItemModel::slotManagerChanged( ScheduleManager *manager )
 {
-    kDebug()<<m_manager<<manager;
+    kDebug(planDbg())<<m_manager<<manager;
     if ( m_manager == manager ) {
         //TODO
 //        refresh();
@@ -1132,7 +1201,7 @@ void ScheduleLogItemModel::slotManagerChanged( ScheduleManager *manager )
 
 void ScheduleLogItemModel::slotScheduleChanged( MainSchedule *sch )
 {
-    kDebug()<<m_schedule<<sch;
+    kDebug(planDbg())<<m_schedule<<sch;
     if ( m_schedule == sch ) {
         refresh();
     }
