@@ -20,13 +20,18 @@
 #include "googledocumentservice.h"
 #include "documentlistwindow.h"
 
+#include <KoGlobal.h>
+
+#include <kwallet.h>
+
 #include <QMessageBox>
 
 
 LoginWindow::LoginWindow(OnlineDocument::DocumentType type, QWidget *parent)
 	: QDialog(parent),
           m_type(type),
-          m_authDialog(new Ui_Dialog)
+          m_authDialog(new Ui_Dialog),
+          m_wallet(0)
 {
     m_authDialog->setupUi(this);
 
@@ -38,6 +43,24 @@ LoginWindow::LoginWindow(OnlineDocument::DocumentType type, QWidget *parent)
     connect(m_authDialog->loginButton, SIGNAL(clicked()), this, SLOT(loginService()));
     connect(m_authDialog->comboBox, SIGNAL(activated(int)), this, SLOT(serviceSelected(int)));
 
+    const QString settingsGroup = "Google-Documents";
+    KConfigGroup interface = KoGlobal::calligraConfig()->group(settingsGroup);
+    if (interface.exists()) {
+        QString userName = interface.readEntry("userEmailId", "");
+        if (!userName.isEmpty()) {
+            m_authDialog->userEdit->setText(userName);
+
+            QString password;
+            if (wallet()) {
+                wallet()->readPassword(QString("%1-%2").arg(settingsGroup).arg(userName), password);
+            }
+
+            if (!password.isEmpty()) {
+                m_authDialog->passwordEdit->setText(password);
+            }
+        }
+    }
+
     m_authDialog->userEdit->setFocus();
     showProgressIndicator(false);
     setWindowTitle("Online Document Services");
@@ -47,10 +70,15 @@ LoginWindow::LoginWindow(OnlineDocument::DocumentType type, QWidget *parent)
 LoginWindow::~LoginWindow()
 {
     delete m_authDialog;
+    delete m_wallet;
 }
 
 void LoginWindow::loginService()
 {
+    if (m_authDialog->saveUserDetails->isChecked()) {
+        saveUserDetails();
+    }
+
     if (0 == m_authDialog->comboBox->currentIndex()) {
         gdoc = new GoogleDocumentService(m_type);
         showProgressIndicator(true);
@@ -62,6 +90,18 @@ void LoginWindow::loginService()
     }
 }
 
+void LoginWindow::saveUserDetails()
+{
+    const QString settingsGroup = "Google-Documents";
+    KConfigGroup interface = KoGlobal::calligraConfig()->group(settingsGroup);
+    interface.writeEntry("userEmailId", m_authDialog->userEdit->text());
+
+    if (wallet()) {
+        wallet()->writePassword(QString("%1-%2").arg(settingsGroup).arg(m_authDialog->userEdit->text()),
+                               m_authDialog->passwordEdit->text());
+    }
+}
+
 void LoginWindow::serviceSelected(int index)
 {
 //    if (index == 0) {
@@ -82,7 +122,7 @@ void LoginWindow::authenticated(bool success, QString errorString)
 //        m_authDialog->label->setText("Successfully authenticated!!! Retreiving document list...");
 //        accept();
     } else {
-        QString msg = "Error occured while signing in ";
+        QString msg = "Error occurred while signing in ";
         if (!errorString.isEmpty()) {
             msg = msg + "- " + errorString;
         }
@@ -100,3 +140,18 @@ void LoginWindow::updateProgress(QString msg)
 {
     m_authDialog->headerLabel->setText(msg);
 }
+
+KWallet::Wallet *LoginWindow::wallet()
+{
+    if (!m_wallet) {
+        m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), winId());
+        connect(m_wallet, SIGNAL(walletClosed()), this, SLOT(closeWallet()));
+    }
+    return m_wallet;
+}
+
+void LoginWindow::closeWallet()
+{
+    delete m_wallet;
+    m_wallet = 0;
+}
